/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.benchmark;

/**
 * BenchmarkResult describes a single benchmark result.
 *
 * @author Jason Winnebeck
 */
public class BenchmarkResult {
	//dimensions
	private boolean sizeManagement;
	private int     numRecords;
	private String  implementation;

	//environment
	private String osName;
	private String osVersion;

	//creation stats
	private double createTimeSec;
	private long   createSectorReads;
	private long   createSectorWrites;

	//load stats
	private double loadTimeSec;
	private long   loadSectorReads;
	private long   loadSectorWrites;
	private double loadReadSec;
	private double loadWriteSec;
	private long   loadUserModeTicks;
	private long   loadKernelModeTicks;

	private long   databaseSizeBytes;

	public static final String HEADER =
			"sizeManagement, numRecords, implementation, osName, osVersion, createTimeSec, createSectorReads" +
			", createSectorWrites, loadTimeSec, loadSectorReads, loadSectorWrites, loadReadSec" +
			", loadWriteSec, loadUserModeTicks, loadKernelModeTicks, databaseSizeBytes";

	public BenchmarkResult() {
		osName = System.getProperty( "os.name" );
		osVersion = System.getProperty( "os.version" );
	}

	public boolean isSizeManagement() {
		return sizeManagement;
	}

	public void setSizeManagement( boolean sizeManagement ) {
		this.sizeManagement = sizeManagement;
	}

	public int getNumRecords() {
		return numRecords;
	}

	public void setNumRecords( int numRecords ) {
		this.numRecords = numRecords;
	}

	public String getImplementation() {
		return implementation;
	}

	public void setImplementation( String implementation ) {
		this.implementation = implementation;
	}

	public double getCreateTimeSec() {
		return createTimeSec;
	}

	public void setCreateTimeSec( double createTimeSec ) {
		this.createTimeSec = createTimeSec;
	}

	public long getCreateSectorReads() {
		return createSectorReads;
	}

	public void setCreateSectorReads( long createSectorReads ) {
		this.createSectorReads = createSectorReads;
	}

	public long getCreateSectorWrites() {
		return createSectorWrites;
	}

	public void setCreateSectorWrites( long createSectorWrites ) {
		this.createSectorWrites = createSectorWrites;
	}

	public double getLoadTimeSec() {
		return loadTimeSec;
	}

	public void setLoadTimeSec( double loadTimeSec ) {
		this.loadTimeSec = loadTimeSec;
	}

	public long getLoadSectorReads() {
		return loadSectorReads;
	}

	public void setLoadSectorReads( long loadSectorReads ) {
		this.loadSectorReads = loadSectorReads;
	}

	public long getLoadSectorWrites() {
		return loadSectorWrites;
	}

	public void setLoadSectorWrites( long loadSectorWrites ) {
		this.loadSectorWrites = loadSectorWrites;
	}

	public double getLoadReadSec() {
		return loadReadSec;
	}

	public void setLoadReadSec( double loadReadSec ) {
		this.loadReadSec = loadReadSec;
	}

	public double getLoadWriteSec() {
		return loadWriteSec;
	}

	public void setLoadWriteSec( double loadWriteSec ) {
		this.loadWriteSec = loadWriteSec;
	}

	public long getLoadUserModeTicks() {
		return loadUserModeTicks;
	}

	public void setLoadUserModeTicks( long loadUserModeTicks ) {
		this.loadUserModeTicks = loadUserModeTicks;
	}

	public long getLoadKernelModeTicks() {
		return loadKernelModeTicks;
	}

	public void setLoadKernelModeTicks( long loadKernelModeTicks ) {
		this.loadKernelModeTicks = loadKernelModeTicks;
	}

	public long getDatabaseSizeBytes() {
		return databaseSizeBytes;
	}

	public void setDatabaseSizeBytes( long databaseSizeBytes ) {
		this.databaseSizeBytes = databaseSizeBytes;
	}

	@Override
	public boolean equals( Object o ) {
		if ( this == o ) return true;
		if ( o == null || getClass() != o.getClass() ) return false;

		BenchmarkResult that = (BenchmarkResult) o;

		if ( createSectorReads != that.createSectorReads ) return false;
		if ( createSectorWrites != that.createSectorWrites ) return false;
		if ( Double.compare( that.createTimeSec, createTimeSec ) != 0 ) return false;
		if ( databaseSizeBytes != that.databaseSizeBytes ) return false;
		if ( loadKernelModeTicks != that.loadKernelModeTicks ) return false;
		if ( Double.compare( that.loadReadSec, loadReadSec ) != 0 ) return false;
		if ( loadSectorReads != that.loadSectorReads ) return false;
		if ( loadSectorWrites != that.loadSectorWrites ) return false;
		if ( Double.compare( that.loadTimeSec, loadTimeSec ) != 0 ) return false;
		if ( loadUserModeTicks != that.loadUserModeTicks ) return false;
		if ( Double.compare( that.loadWriteSec, loadWriteSec ) != 0 ) return false;
		if ( numRecords != that.numRecords ) return false;
		if ( sizeManagement != that.sizeManagement ) return false;
		if ( implementation != null ? !implementation.equals( that.implementation ) :
		     that.implementation != null ) return false;

		return true;
	}

	@Override
	public int hashCode() {
		int result;
		long temp;
		result = ( sizeManagement ? 1 : 0 );
		result = 31 * result + numRecords;
		result = 31 * result + ( implementation != null ? implementation.hashCode() : 0 );
		temp = createTimeSec != +0.0d ? Double.doubleToLongBits( createTimeSec ) : 0L;
		result = 31 * result + (int) ( temp ^ ( temp >>> 32 ) );
		result = 31 * result + (int) ( createSectorReads ^ ( createSectorReads >>> 32 ) );
		result = 31 * result + (int) ( createSectorWrites ^ ( createSectorWrites >>> 32 ) );
		temp = loadTimeSec != +0.0d ? Double.doubleToLongBits( loadTimeSec ) : 0L;
		result = 31 * result + (int) ( temp ^ ( temp >>> 32 ) );
		result = 31 * result + (int) ( loadSectorReads ^ ( loadSectorReads >>> 32 ) );
		result = 31 * result + (int) ( loadSectorWrites ^ ( loadSectorWrites >>> 32 ) );
		temp = loadReadSec != +0.0d ? Double.doubleToLongBits( loadReadSec ) : 0L;
		result = 31 * result + (int) ( temp ^ ( temp >>> 32 ) );
		temp = loadWriteSec != +0.0d ? Double.doubleToLongBits( loadWriteSec ) : 0L;
		result = 31 * result + (int) ( temp ^ ( temp >>> 32 ) );
		result = 31 * result + (int) ( loadUserModeTicks ^ ( loadUserModeTicks >>> 32 ) );
		result = 31 * result + (int) ( loadKernelModeTicks ^ ( loadKernelModeTicks >>> 32 ) );
		result = 31 * result + (int) ( databaseSizeBytes ^ ( databaseSizeBytes >>> 32 ) );
		return result;
	}

	@Override
	public String toString() {
		return sizeManagement +
		       "," + numRecords +
		       "," + sanitize( implementation ) +

		       "," + sanitize( osName ) +
		       "," + sanitize( osVersion ) +

		       "," + createTimeSec +
		       "," + createSectorReads +
		       "," + createSectorWrites +

		       "," + loadTimeSec +
		       "," + loadSectorReads +
		       "," + loadSectorWrites +
		       "," + loadReadSec +
		       "," + loadWriteSec +
		       "," + loadUserModeTicks +
		       "," + loadKernelModeTicks +
	         "," + databaseSizeBytes;
	}

	private static String sanitize( String s ) {
		return s.replace( ' ', '_' ).replace( ',', '_' ).replace( '"', '_' );
	}
}
