/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.benchmark;

import org.gillius.realdb.concept.data.DataHandlingException;
import org.gillius.realdb.concept.data.VehicleDataHandler;

import java.util.HashMap;
import java.util.Map;

/**
 * BooleanRemoveDuplicatesVehicleDataHandler removes duplicate rows for boolean streams.
 *
 * @author Jason Winnebeck
 */
public class BooleanRemoveDuplicatesVehicleDataHandler extends FilterVehicleDataHandler {
	private int removed = 0;

	private final Map<Integer, Boolean> cache = new HashMap<Integer, Boolean>();

	public BooleanRemoveDuplicatesVehicleDataHandler( VehicleDataHandler handler ) {
		super( handler );
	}

	@Override
	public void dataRead( int stream, long time, boolean value, boolean discontinuity )
			throws DataHandlingException {
		Boolean cached = cache.get( stream );
		if ( cached == null || cached.booleanValue() != value ) {
			cache.put( stream, value );
			super.dataRead( stream, time, value, discontinuity );
		} //else skip the row
		else {
			removed++;
		}
	}

	@Override
	public void endStream() throws DataHandlingException {
		super.endStream();
		System.out.println( "REMOVED " + removed );
	}
}
