/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.benchmark;

import java.util.Properties;

/**
 * ConnectionParameters specifies parameters to connect to a database through a JDBC driver.
 *
 * @author Jason Winnebeck
 */
public class ConnectionParameters {
	private String className;
	private String protocol;
	private String url;
	private String user;
	private String password;

	public ConnectionParameters() {
	}

	public ConnectionParameters( String className, String protocol, String url, String user,
	                             String password ) {
		this.className = className;
		this.protocol = protocol;
		this.url = url;
		this.user = user;
		this.password = password;
	}

	public void load( Properties props ) {
		setClassName( props.getProperty( "className", className ) );
		setProtocol( props.getProperty( "protocol", protocol ) );
		setUrl( props.getProperty( "url", url ) );
		setUser( props.getProperty( "user", user ) );
		setPassword( props.getProperty( "password", password ) );
	}

	public String getClassName() {
		return className;
	}

	public void setClassName( String className ) {
		this.className = className;
	}

	public String getProtocol() {
		return protocol;
	}

	public void setProtocol( String protocol ) {
		this.protocol = protocol;
	}

	public String getUrl() {
		return url;
	}

	public void setUrl( String url ) {
		this.url = url;
	}

	public String getUser() {
		return user;
	}

	public void setUser( String user ) {
		this.user = user;
	}

	public String getPassword() {
		return password;
	}

	public void setPassword( String password ) {
		this.password = password;
	}
}
