/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.benchmark;

import javax.swing.*;
import javax.swing.event.DocumentEvent;
import javax.swing.event.DocumentListener;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyEvent;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

public class ConnectionParametersDialog extends JDialog {
	private JPanel contentPane;
	private JButton buttonOK;
	private JButton buttonCancel;
	private JTextField classNameField;
	private JTextField protocolField;
	private JTextField urlField;
	private JTextField userField;
	private JPasswordField passwordPasswordField;
	private JLabel jdbcUrlLabel;

	private final ConnectionParameters params;

	public ConnectionParametersDialog( Component parent, ConnectionParameters params ) {
		super( parent == null ? null : SwingUtilities.windowForComponent( parent ) );

		this.params = params;

		setContentPane( contentPane );
		setModal( true );
		getRootPane().setDefaultButton( buttonOK );

		buttonOK.addActionListener( new ActionListener() {
			public void actionPerformed( ActionEvent e ) {
				onOK();
			}
		} );

		buttonCancel.addActionListener( new ActionListener() {
			public void actionPerformed( ActionEvent e ) {
				onCancel();
			}
		} );

// call onCancel() when cross is clicked
		setDefaultCloseOperation( DO_NOTHING_ON_CLOSE );
		addWindowListener( new WindowAdapter() {
			public void windowClosing( WindowEvent e ) {
				onCancel();
			}
		} );

// call onCancel() on ESCAPE
		contentPane.registerKeyboardAction( new ActionListener() {
			public void actionPerformed( ActionEvent e ) {
				onCancel();
			}
		}, KeyStroke.getKeyStroke( KeyEvent.VK_ESCAPE, 0 ),
		                                    JComponent.WHEN_ANCESTOR_OF_FOCUSED_COMPONENT );

		DocumentListener jdbcUrlListener = new DocumentListener() {
			@Override
			public void insertUpdate( DocumentEvent e ) {
				updateJdbcUrlLabel();
			}

			@Override
			public void removeUpdate( DocumentEvent e ) {
				updateJdbcUrlLabel();
			}

			@Override
			public void changedUpdate( DocumentEvent e ) {
			}
		};
		protocolField.getDocument().addDocumentListener( jdbcUrlListener );
		urlField.getDocument().addDocumentListener( jdbcUrlListener );

		setData( params );
		updateJdbcUrlLabel();
	}

	private void updateJdbcUrlLabel() {
		jdbcUrlLabel.setText( "JDBC URL: jdbc:" + protocolField.getText() + ":" + urlField.getText() );
	}

	private void onOK() {
		getData( params );
		dispose();
	}

	private void onCancel() {
		dispose();
	}

	private void setData( ConnectionParameters data ) {
		classNameField.setText( data.getClassName() );
		protocolField.setText( data.getProtocol() );
		urlField.setText( data.getUrl() );
		userField.setText( data.getUser() );
		passwordPasswordField.setText( data.getPassword() );
	}

	private void getData( ConnectionParameters data ) {
		data.setClassName( classNameField.getText() );
		data.setProtocol( protocolField.getText() );
		data.setUrl( urlField.getText() );
		data.setUser( userField.getText() );
		data.setPassword( new String( passwordPasswordField.getPassword() ) );
		//not paranoid about memory hackers with modern OS; using String
	}

	{
// GUI initializer generated by IntelliJ IDEA GUI Designer
// >>> IMPORTANT!! <<<
// DO NOT EDIT OR ADD ANY CODE HERE!
		$$$setupUI$$$();
	}

	/**
	 * Method generated by IntelliJ IDEA GUI Designer >>> IMPORTANT!! <<< DO NOT edit this method OR
	 * call it in your code!
	 *
	 * @noinspection ALL
	 */
	private void $$$setupUI$$$() {
		contentPane = new JPanel();
		contentPane.setLayout( new GridBagLayout() );
		final JPanel panel1 = new JPanel();
		panel1.setLayout( new GridBagLayout() );
		GridBagConstraints gbc;
		gbc = new GridBagConstraints();
		gbc.gridx = 0;
		gbc.gridy = 0;
		gbc.weightx = 1.0;
		gbc.weighty = 1.0;
		gbc.fill = GridBagConstraints.BOTH;
		gbc.insets = new Insets( 8, 8, 8, 8 );
		contentPane.add( panel1, gbc );
		final JLabel label1 = new JLabel();
		label1.setText( "JDBC Driver Class" );
		gbc = new GridBagConstraints();
		gbc.gridx = 0;
		gbc.gridy = 0;
		gbc.anchor = GridBagConstraints.WEST;
		gbc.insets = new Insets( 8, 8, 8, 8 );
		panel1.add( label1, gbc );
		classNameField = new JTextField();
		classNameField.setColumns( 25 );
		gbc = new GridBagConstraints();
		gbc.gridx = 1;
		gbc.gridy = 0;
		gbc.weightx = 1.0;
		gbc.anchor = GridBagConstraints.WEST;
		gbc.fill = GridBagConstraints.HORIZONTAL;
		gbc.insets = new Insets( 8, 8, 8, 8 );
		panel1.add( classNameField, gbc );
		final JLabel label2 = new JLabel();
		label2.setText( "Protocol" );
		gbc = new GridBagConstraints();
		gbc.gridx = 0;
		gbc.gridy = 1;
		gbc.anchor = GridBagConstraints.WEST;
		gbc.insets = new Insets( 8, 8, 8, 8 );
		panel1.add( label2, gbc );
		protocolField = new JTextField();
		gbc = new GridBagConstraints();
		gbc.gridx = 1;
		gbc.gridy = 1;
		gbc.anchor = GridBagConstraints.WEST;
		gbc.fill = GridBagConstraints.HORIZONTAL;
		gbc.insets = new Insets( 8, 8, 8, 8 );
		panel1.add( protocolField, gbc );
		final JLabel label3 = new JLabel();
		label3.setText( "URL" );
		gbc = new GridBagConstraints();
		gbc.gridx = 0;
		gbc.gridy = 2;
		gbc.anchor = GridBagConstraints.WEST;
		gbc.insets = new Insets( 8, 8, 8, 8 );
		panel1.add( label3, gbc );
		urlField = new JTextField();
		gbc = new GridBagConstraints();
		gbc.gridx = 1;
		gbc.gridy = 2;
		gbc.anchor = GridBagConstraints.WEST;
		gbc.fill = GridBagConstraints.HORIZONTAL;
		gbc.insets = new Insets( 8, 8, 8, 8 );
		panel1.add( urlField, gbc );
		final JLabel label4 = new JLabel();
		label4.setText( "User" );
		gbc = new GridBagConstraints();
		gbc.gridx = 0;
		gbc.gridy = 3;
		gbc.anchor = GridBagConstraints.WEST;
		gbc.insets = new Insets( 8, 8, 8, 8 );
		panel1.add( label4, gbc );
		userField = new JTextField();
		gbc = new GridBagConstraints();
		gbc.gridx = 1;
		gbc.gridy = 3;
		gbc.anchor = GridBagConstraints.WEST;
		gbc.fill = GridBagConstraints.HORIZONTAL;
		gbc.insets = new Insets( 8, 8, 8, 8 );
		panel1.add( userField, gbc );
		final JLabel label5 = new JLabel();
		label5.setText( "Password" );
		gbc = new GridBagConstraints();
		gbc.gridx = 0;
		gbc.gridy = 4;
		gbc.anchor = GridBagConstraints.WEST;
		gbc.insets = new Insets( 8, 8, 8, 8 );
		panel1.add( label5, gbc );
		passwordPasswordField = new JPasswordField();
		gbc = new GridBagConstraints();
		gbc.gridx = 1;
		gbc.gridy = 4;
		gbc.anchor = GridBagConstraints.WEST;
		gbc.fill = GridBagConstraints.HORIZONTAL;
		gbc.insets = new Insets( 8, 8, 8, 8 );
		panel1.add( passwordPasswordField, gbc );
		jdbcUrlLabel = new JLabel();
		jdbcUrlLabel.setText( "JDBC URL:" );
		gbc = new GridBagConstraints();
		gbc.gridx = 0;
		gbc.gridy = 5;
		gbc.gridwidth = 2;
		gbc.anchor = GridBagConstraints.WEST;
		gbc.insets = new Insets( 8, 8, 8, 8 );
		panel1.add( jdbcUrlLabel, gbc );
		final JPanel panel2 = new JPanel();
		panel2.setLayout( new FlowLayout( FlowLayout.RIGHT, 5, 0 ) );
		gbc = new GridBagConstraints();
		gbc.gridx = 0;
		gbc.gridy = 1;
		gbc.fill = GridBagConstraints.BOTH;
		gbc.insets = new Insets( 8, 8, 8, 8 );
		contentPane.add( panel2, gbc );
		buttonOK = new JButton();
		buttonOK.setText( "OK" );
		panel2.add( buttonOK );
		buttonCancel = new JButton();
		buttonCancel.setText( "Cancel" );
		panel2.add( buttonCancel );
		label1.setLabelFor( classNameField );
		label2.setLabelFor( protocolField );
		label3.setLabelFor( urlField );
		label4.setLabelFor( userField );
		label5.setLabelFor( passwordPasswordField );
	}

	/**
	 * @noinspection ALL
	 */
	public JComponent $$$getRootComponent$$$() {
		return contentPane;
	}
}
