/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.benchmark;

import org.gillius.realdb.concept.data.DataHandlingException;
import org.gillius.realdb.concept.data.VehicleDataHandler;

/**
 * CountingVehicleDataHandler counts the number of processed data events. It can also be used to
 * truncate the event stream. Throwing an exception with the message {@link #EX_MESSAGE} will
 * happen after the event numbered at the limit is processed.
 *
 * @author Jason Winnebeck
 */
public class CountingVehicleDataHandler extends FilterVehicleDataHandler {
	public static final String EX_MESSAGE = "Early termination";

	private int count = 0;
	private int limit = Integer.MAX_VALUE;

	public CountingVehicleDataHandler( VehicleDataHandler handler ) {
		super( handler );
	}

	public int getLimit() {
		return limit;
	}

	public void setLimit( int limit ) {
		this.limit = limit;
	}

	@Override
	public void dataRead( int stream, long time, float value, boolean discontinuity )
			throws DataHandlingException {
		super.dataRead( stream, time, value, discontinuity );
		++count;
		if ( count >= limit )
			throw new DataHandlingException( EX_MESSAGE );
	}

	@Override
	public void dataRead( int stream, long time, boolean value, boolean discontinuity )
			throws DataHandlingException {
		super.dataRead( stream, time, value, discontinuity );
		++count;
		if ( count >= limit )
			throw new DataHandlingException( EX_MESSAGE );
	}

	public int getCount() {
		return count;
	}

	public void reset() {
		count = 0;
	}
}
