/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.benchmark;

import org.gillius.realdb.concept.data.DataHandlingException;
import org.gillius.realdb.concept.data.VehicleDataHandler;

/**
 * FilterVehicleDataHandler delegates all calls to a wrapper handler, if it is set. Subclasses then
 * choose to call super or not.
 *
 * @author Jason Winnebeck
 */
public class FilterVehicleDataHandler implements VehicleDataHandler {
	private VehicleDataHandler handler;

	public FilterVehicleDataHandler( VehicleDataHandler handler ) {
		this.handler = handler;
	}

	@Override
	public void startStream() throws DataHandlingException {
		if ( handler != null )
			handler.startStream();
	}

	@Override
	public void dataRead( int stream, long time, float value, boolean discontinuity )
			throws DataHandlingException {
		if ( handler != null )
			handler.dataRead( stream, time, value, discontinuity );
	}

	@Override
	public void dataRead( int stream, long time, boolean value, boolean discontinuity )
			throws DataHandlingException {
		if ( handler != null )
			handler.dataRead( stream, time, value, discontinuity );
	}

	@Override
	public void endStream() throws DataHandlingException {
		if ( handler != null )
			handler.endStream();
	}
}
