/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.benchmark;

import java.io.File;
import java.io.PrintStream;
import java.util.Arrays;

/**
 * MultiBenchmark
 */
public class MultiBenchmark {
	public static void main( String[] args ) throws Exception {
		File dataDir = new File( "data" );
		File benchmarkProps = new File( dataDir, "benchmark.properties" );
		if ( !benchmarkProps.exists() ) {
			System.err.println( "benchmark properties file " + benchmarkProps.getAbsolutePath() +
			                    " does not exist" );
			System.exit( 1 );
		}

		System.out.println( "Running benchmarks: " + Arrays.toString( args ) );

		for ( String arg : args ) {
			File prop = new File( dataDir, arg + ".properties" );
			if ( !prop.exists() ) {
				System.err.println( "benchmark properties file " + prop.getAbsolutePath() + " does not exist" );
				System.exit( 2 );
			}
		}

		File outputFile = new File( "output.txt" );

		System.out.println( "Output will be redirected to " + outputFile.getAbsolutePath() );

		PrintStream output = new PrintStream( outputFile );

		System.setOut( output );
		System.setErr( output );

		for ( String arg : args ) {
			Benchmark.main( new String[] { benchmarkProps.getAbsolutePath(),
			                               new File( dataDir, arg + ".properties" ).getAbsolutePath() } );
		}
	}
}
