/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.benchmark;

import java.io.Reader;
import java.sql.Connection;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.Scanner;

/**
 * SqlRunner runs a SQL file against a Connection or Statement, one SQL statement at a time. Every
 * statement must end with a semicolon.
 *
 * @author Jason Winnebeck
 */
public class SqlRunner {
	public static void run( Connection conn, Reader input ) throws SQLException {
		Statement stmt = conn.createStatement();
		try {
			run( stmt, input );
		} finally {
			stmt.close();
		}
	}

	private static void run( Statement stmt, Reader input ) throws SQLException {
		Scanner scanner = new Scanner( input );
		scanner.useDelimiter( ";" );

		while( scanner.hasNext() ) {
			String sql = scanner.next().trim();
			try {
				if ( !sql.isEmpty() )
					stmt.execute( sql );
			} catch ( SQLException e ) {
				throw new SQLException( "Error running query: " + sql,
				                        e.getSQLState(), e.getErrorCode(), e );
			}
		}
	}
}
