/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.tools.gui;

import javax.swing.*;
import javax.swing.tree.TreeNode;

/**
 * BrowserImpl -- all calls should happen on the event thread.
 *
 * @author Jason Winnebeck
 */
public class BrowserImpl extends DefaultBasicModel implements BrowserModel, BrowserController {

	private DBNode treeRoot;
	private JComponent display;
	private DBNode selectedNode;

	public BrowserImpl() {
		treeRoot = new DBNode( "Database", this, false );
		setSelectedNode( treeRoot );
	}

	public TreeNode getTreeRoot() {
		return treeRoot;
	}

	public void setTreeRoot( DBNode newVal ) {
		TreeNode oldVal = treeRoot;
		treeRoot = newVal;
		pcs.firePropertyChange( "treeRoot", oldVal, newVal );

		setSelectedNode( newVal );
	}

	public JComponent getDisplay() {
		return display;
	}

	public void setDisplay( JComponent newVal ) {
		JComponent oldVal = display;
		display = newVal;
		pcs.firePropertyChange( "display", oldVal, newVal );
	}

	public DBNode getSelectedNode() {
		return selectedNode;
	}

	public void setSelectedNode( DBNode newVal ) {
		setDisplay( DisplayFactory.makeDisplay( newVal.getSource() ) );
		DBNode oldVal = selectedNode;
		selectedNode = newVal;
		pcs.firePropertyChange( "selectedNode", oldVal, newVal );
	}
}
