/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.tools.gui;

import javax.swing.*;
import javax.swing.event.TreeSelectionEvent;
import javax.swing.event.TreeSelectionListener;
import javax.swing.tree.DefaultTreeModel;
import javax.swing.tree.TreeNode;
import javax.swing.tree.TreePath;
import java.awt.*;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;

/**
 * BrowserView
 *
 * @author Jason Winnebeck
 */
public class BrowserView {
	private JPanel panel;
	private JTree dbTree;
	private JPanel contentPanel;

	private final DefaultTreeModel treeModel;

	public BrowserView( BrowserModel model, final BrowserController ctl ) {
		contentPanel.add( model.getDisplay() );

		treeModel = new DefaultTreeModel( model.getTreeRoot() );
		dbTree.setModel( treeModel );
		if ( model.getSelectedNode() != null )
			dbTree.setSelectionPath( new TreePath( model.getSelectedNode().getPath() ) );
		else
			dbTree.setSelectionPath( new TreePath( model.getTreeRoot() ) );

		model.addPropertyChangeListener( SwingProxy.create( new PropertyChangeListener() {
			public void propertyChange( PropertyChangeEvent evt ) {
				handleModelEvent( evt );
			}
		} ) );

		dbTree.addTreeSelectionListener( new TreeSelectionListener() {
			public void valueChanged( TreeSelectionEvent e ) {
				ctl.setSelectedNode( (DBNode) e.getPath().getLastPathComponent() );
			}
		} );
	}

	private void handleModelEvent( PropertyChangeEvent evt ) {
		String name = evt.getPropertyName();
		if ( name.equals( "treeRoot" ) ) {
			treeModel.setRoot( (TreeNode) evt.getNewValue() );
		} else if ( name.equals( "display" ) ) {
			contentPanel.removeAll();
			contentPanel.add( (Component) evt.getNewValue() );
			contentPanel.validate();
		} else if ( name.equals( "selectedNode" ) ) {
			dbTree.setSelectionPath( new TreePath( ( (DBNode) evt.getNewValue() ).getPath() ) );
		}
	}

	public JPanel getPanel() {
		return panel;
	}

	{
// GUI initializer generated by IntelliJ IDEA GUI Designer
// >>> IMPORTANT!! <<<
// DO NOT EDIT OR ADD ANY CODE HERE!
		$$$setupUI$$$();
	}

	/**
	 * Method generated by IntelliJ IDEA GUI Designer >>> IMPORTANT!! <<< DO NOT edit this method OR
	 * call it in your code!
	 *
	 * @noinspection ALL
	 */
	private void $$$setupUI$$$() {
		panel = new JPanel();
		panel.setLayout( new BorderLayout( 0, 0 ) );
		final JSplitPane splitPane1 = new JSplitPane();
		splitPane1.setOneTouchExpandable( true );
		panel.add( splitPane1, BorderLayout.CENTER );
		final JScrollPane scrollPane1 = new JScrollPane();
		splitPane1.setLeftComponent( scrollPane1 );
		dbTree = new JTree();
		dbTree.setOpaque( true );
		dbTree.setPreferredSize( new Dimension( 150, 64 ) );
		scrollPane1.setViewportView( dbTree );
		final JPanel panel1 = new JPanel();
		panel1.setLayout( new BorderLayout( 0, 0 ) );
		splitPane1.setRightComponent( panel1 );
		panel1.setBorder(
				BorderFactory.createTitledBorder( BorderFactory.createEmptyBorder( 8, 8, 8, 8 ), null ) );
		contentPanel = new JPanel();
		contentPanel.setLayout( new BorderLayout( 0, 0 ) );
		panel1.add( contentPanel, BorderLayout.CENTER );
	}

	/**
	 * @noinspection ALL
	 */
	public JComponent $$$getRootComponent$$$() {
		return panel;
	}
}
