/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.tools.gui;

import org.gillius.realdb.metadata.DataStreamInfo;
import org.gillius.realdb.metadata.RecordElement;
import org.gillius.realdb.model.DataStream;

import javax.swing.*;
import javax.swing.table.DefaultTableModel;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

/**
 * DataStreamView provides a view panel for a given DataStream.
 *
 * @author Jason Winnebeck
 */
public class DataStreamView {
	private JLabel streamNameLabel;
	private JLabel idLabel;
	private JTable elementsTable;
	private JPanel panel;
	private JButton viewDataButton;

	public DataStreamView( final DataStream stream ) {
		DataStreamInfo info = stream.getInfo();

		streamNameLabel.setText( info.getName() );
		idLabel.setText( String.valueOf( info.getUserId() ) );

		DefaultTableModel model = new DefaultTableModel();
		model.setColumnIdentifiers( new Object[] { "Id", "Name", "Type", "Nullable", "Codec" } );

		for ( RecordElement e : info.getElements() ) {
			model.addRow( new Object[] {
					e.getPosition(),
					e.getName(),
					e.getType(),
					e.isOptional(),
					e.getCodec().getClass().getSimpleName()
			} );
		}

		elementsTable.setModel( model );

		viewDataButton.addActionListener( new ActionListener() {
			@Override
			public void actionPerformed( ActionEvent e ) {
				new DataStreamDataViewer( stream ).makeAndShowFrame();
			}
		} );
	}

	public JPanel getPanel() {
		return panel;
	}

	{
// GUI initializer generated by IntelliJ IDEA GUI Designer
// >>> IMPORTANT!! <<<
// DO NOT EDIT OR ADD ANY CODE HERE!
		$$$setupUI$$$();
	}

	/**
	 * Method generated by IntelliJ IDEA GUI Designer >>> IMPORTANT!! <<< DO NOT edit this method OR
	 * call it in your code!
	 *
	 * @noinspection ALL
	 */
	private void $$$setupUI$$$() {
		panel = new JPanel();
		panel.setLayout( new GridBagLayout() );
		streamNameLabel = new JLabel();
		streamNameLabel.setText( "Stream Name" );
		GridBagConstraints gbc;
		gbc = new GridBagConstraints();
		gbc.gridx = 0;
		gbc.gridy = 0;
		gbc.gridwidth = 2;
		gbc.anchor = GridBagConstraints.WEST;
		gbc.insets = new Insets( 8, 8, 8, 8 );
		panel.add( streamNameLabel, gbc );
		final JLabel label1 = new JLabel();
		label1.setText( "ID" );
		gbc = new GridBagConstraints();
		gbc.gridx = 0;
		gbc.gridy = 1;
		gbc.anchor = GridBagConstraints.WEST;
		gbc.insets = new Insets( 8, 8, 8, 8 );
		panel.add( label1, gbc );
		idLabel = new JLabel();
		idLabel.setText( "Label" );
		gbc = new GridBagConstraints();
		gbc.gridx = 1;
		gbc.gridy = 1;
		gbc.anchor = GridBagConstraints.WEST;
		gbc.insets = new Insets( 8, 8, 8, 8 );
		panel.add( idLabel, gbc );
		final JLabel label2 = new JLabel();
		label2.setText( "Elements" );
		gbc = new GridBagConstraints();
		gbc.gridx = 0;
		gbc.gridy = 2;
		gbc.anchor = GridBagConstraints.WEST;
		gbc.insets = new Insets( 8, 8, 8, 8 );
		panel.add( label2, gbc );
		final JScrollPane scrollPane1 = new JScrollPane();
		gbc = new GridBagConstraints();
		gbc.gridx = 1;
		gbc.gridy = 2;
		gbc.weightx = 1.0;
		gbc.weighty = 1.0;
		gbc.fill = GridBagConstraints.BOTH;
		gbc.insets = new Insets( 8, 8, 8, 8 );
		panel.add( scrollPane1, gbc );
		elementsTable = new JTable();
		elementsTable.setEnabled( false );
		scrollPane1.setViewportView( elementsTable );
		final JPanel panel1 = new JPanel();
		panel1.setLayout( new FlowLayout( FlowLayout.CENTER, 5, 5 ) );
		gbc = new GridBagConstraints();
		gbc.gridx = 1;
		gbc.gridy = 3;
		gbc.anchor = GridBagConstraints.EAST;
		gbc.fill = GridBagConstraints.VERTICAL;
		panel.add( panel1, gbc );
		viewDataButton = new JButton();
		viewDataButton.setText( "View Data" );
		viewDataButton.setMnemonic( 'V' );
		viewDataButton.setDisplayedMnemonicIndex( 0 );
		panel1.add( viewDataButton );
	}

	/**
	 * @noinspection ALL
	 */
	public JComponent $$$getRootComponent$$$() {
		return panel;
	}
}
