/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.tools.gui;

import org.gillius.realdb.model.Database;

import java.io.File;

/**
 * DatabaseSelectionImpl -- all calls should occur outside of the Swing event thread.
 *
 * @author Jason Winnebeck
 */
public class DatabaseSelectionImpl extends DefaultBasicModel
		implements DatabaseSelectionModel, DatabaseSelectionController {

	private boolean  loading  = false;
	private String   databasePath = null;
	private Database database = null;

	public boolean isLoading() {
		return loading;
	}

	private DatabaseSelectionImpl setLoading( boolean newVal ) {
		boolean oldVal = loading;
		loading = newVal;
		pcs.firePropertyChange( "loading", oldVal, newVal );
		return this;
	}

	public Database getDatabase() {
		return database;
	}

	private DatabaseSelectionImpl setDatabase( Database newVal ) {
		Database oldVal = database;
		database = newVal;
		pcs.firePropertyChange( "database", oldVal, newVal );
		return this;
	}

	public String getDatabasePath() {
		return databasePath;
	}

	public void setDatabasePath( String newVal ) {
		openDatabase( newVal );
		String oldVal = databasePath;
		databasePath = newVal;
		pcs.firePropertyChange( "databasePath", oldVal, newVal );
	}

	private void openDatabase( String dbPath ) {
		setLoading( true );
		File f = new File( dbPath );

		try {
			setDatabase( Database.load( f ) );
		} catch ( Exception e ) {
			setError( "Error loading database", e );
		} finally {
			setLoading( false );
		}
	}
}
