/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.tools.gui;

import javax.swing.*;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.io.File;

/**
 * DatabaseSelectionView
 *
 * @author Jason Winnebeck
 */
public class DatabaseSelectionView {
	private JPanel panel;
	private JTextField dbNameField;
	private JButton selectorButton;
	private JButton openButton;

	private final JComponent[] enableGroup;

	private final DatabaseSelectionController ctl;

	public DatabaseSelectionView( DatabaseSelectionModel model, DatabaseSelectionController ctl
	) {
		this.ctl = ctl;

		enableGroup = new JComponent[] { dbNameField, selectorButton, openButton };

		//Sync to model
		dbNameField.setText( model.getDatabasePath() );
		for ( JComponent comp : enableGroup ) {
			comp.setEnabled( !model.isLoading() );
		}

		//Set up event listeners
		model.addPropertyChangeListener(
				SwingProxy.create( new PropertyChangeListener() {
					public void propertyChange( PropertyChangeEvent evt ) {
						modelChanged( evt );
					}
				} ) );

		selectorButton.addActionListener( new ActionListener() {
			public void actionPerformed( ActionEvent e ) {
				showDbSelectDialog();
			}
		} );
		openButton.addActionListener( new ActionListener() {
			public void actionPerformed( ActionEvent e ) {
				openDatabase();
			}
		} );
	}

	public JPanel getPanel() {
		return panel;
	}

	private void modelChanged( PropertyChangeEvent evt ) {
		String name = evt.getPropertyName();
		if ( name.equals( "isLoading" ) ) {
			for ( JComponent comp : enableGroup ) {
				comp.setEnabled( !(Boolean) evt.getNewValue() );
			}

		} else if ( name.equals( "error" ) ) {
			ErrorDialog.show( (ModelError) evt.getNewValue(), panel );

		} else if ( name.equals( "databasePath" ) ) {
			dbNameField.setText( evt.getNewValue().toString() );
		}
	}

	private void showDbSelectDialog() {
		JFileChooser chooser = new JFileChooser();

		File current = new File( dbNameField.getText() );
		if ( current.isFile() ) {
			chooser.setCurrentDirectory( current.getParentFile() );
		} else if ( current.isDirectory() ) {
			chooser.setCurrentDirectory( current );
		} else {
			chooser.setCurrentDirectory( new File( "." ) );
		}

		int ret = chooser.showOpenDialog( panel );
		if ( ret == JFileChooser.APPROVE_OPTION ) {
			dbNameField.setText( chooser.getSelectedFile().getAbsolutePath() );
		}
	}

	private void openDatabase() {
		ctl.setDatabasePath( dbNameField.getText() );
	}

	{
// GUI initializer generated by IntelliJ IDEA GUI Designer
// >>> IMPORTANT!! <<<
// DO NOT EDIT OR ADD ANY CODE HERE!
		$$$setupUI$$$();
	}

	/**
	 * Method generated by IntelliJ IDEA GUI Designer >>> IMPORTANT!! <<< DO NOT edit this method OR
	 * call it in your code!
	 *
	 * @noinspection ALL
	 */
	private void $$$setupUI$$$() {
		panel = new JPanel();
		panel.setLayout( new BorderLayout( 0, 0 ) );
		final JPanel panel1 = new JPanel();
		panel1.setLayout( new FlowLayout( FlowLayout.CENTER, 5, 5 ) );
		panel.add( panel1, BorderLayout.CENTER );
		dbNameField = new JTextField();
		dbNameField.setColumns( 30 );
		panel1.add( dbNameField );
		selectorButton = new JButton();
		selectorButton.setText( "..." );
		panel1.add( selectorButton );
		openButton = new JButton();
		openButton.setText( "Open" );
		panel1.add( openButton );
		final JPanel panel2 = new JPanel();
		panel2.setLayout( new FlowLayout( FlowLayout.CENTER, 5, 5 ) );
		panel.add( panel2, BorderLayout.NORTH );
		final JLabel label1 = new JLabel();
		label1.setText( "Please select a database" );
		panel2.add( label1 );
	}

	/**
	 * @noinspection ALL
	 */
	public JComponent $$$getRootComponent$$$() {
		return panel;
	}
}
