/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.tools.gui;

import org.gillius.realdb.metadata.DataStreamInfo;
import org.gillius.realdb.model.DataStream;
import org.gillius.realdb.model.Database;

import java.util.TreeMap;

/**
 * DatabaseTreeBuilder builds a tree of DBNode from a Database.
 *
 * @author Jason Winnebeck
 */
public class DatabaseTreeBuilder {

	public static DBNode build( Database db ) {
		DBNode root = new DBNode( "Database", db, true );

		TreeMap<Integer, DataStream> streams = new TreeMap<Integer, DataStream>( db.getStreamsMap() );

		for ( DataStream stream : streams.values() ) {
			DataStreamInfo info = stream.getInfo();
			root.add( new DBNode( info.getUserId() + ": " + info.getName(), stream, false ) );
		}

		return root;
	}
}
