/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.tools.gui;

import org.gillius.realdb.metadata.MetadataSection;
import org.gillius.realdb.model.Database;

import javax.swing.*;
import javax.swing.table.DefaultTableModel;
import java.awt.*;
import java.text.NumberFormat;
import java.util.Map;

/**
 * DatabaseView
 *
 * @author Jason Winnebeck
 */
public class DatabaseView {
	private JPanel panel;
	private JLabel dbSizeLabel;
	private JLabel blockSizeLabel;
	private JLabel numStreamsLabel;
	private JLabel dataBlockSizeLabel;
	private JLabel maxStreamsLabel;
	private JTable sectionTable;
	private JLabel dataUsageLabel;

	public DatabaseView( Database db ) {
		$$$setupUI$$$();
		dbSizeLabel.setText( ( db.getSizeInBlocks() * db.getBlockSize() ) + " bytes (" +
		                     db.getSizeInBlocks() + " blocks)" );
		blockSizeLabel.setText( db.getBlockSize() + " bytes" );
		numStreamsLabel.setText( String.valueOf( db.getStreams().size() ) );

		MetadataSection meta = db.getMetadata();
		dataBlockSizeLabel.setText( ( meta.getDataBlockSize() * db.getBlockSize() ) + " bytes" );
		maxStreamsLabel.setText( String.valueOf( meta.getMaxStreams() ) );

		NumberFormat format = NumberFormat.getPercentInstance();
		format.setMaximumFractionDigits( 2 );

		String used = format.format( db.getDataBlocksUsed() / (double) db.getTotalDataBlocks() );
		dataUsageLabel.setText( String.format(
				"%s of %s used (%s)",
				db.getDataBlocksUsed(), db.getTotalDataBlocks(), used ) );

		DefaultTableModel model = new DefaultTableModel();
		model.setColumnIdentifiers( new Object[] { "Section", "Blocks", "Percent" } );
		for ( Map.Entry<String, Integer> section : db.getSectionSizes().entrySet() ) {
			model.addRow( new Object[] {
					section.getKey(), section.getValue(),
					format.format( section.getValue() / (double) db.getSizeInBlocks() )
			} );
		}
		sectionTable.setModel( model );
	}

	public JPanel getPanel() {
		return panel;
	}

	/**
	 * Method generated by IntelliJ IDEA GUI Designer >>> IMPORTANT!! <<< DO NOT edit this method OR
	 * call it in your code!
	 *
	 * @noinspection ALL
	 */
	private void $$$setupUI$$$() {
		panel = new JPanel();
		panel.setLayout( new BorderLayout( 8, 8 ) );
		panel.setBorder(
				BorderFactory.createTitledBorder( BorderFactory.createEmptyBorder( 8, 8, 8, 8 ), null ) );
		final JPanel panel1 = new JPanel();
		panel1.setLayout( new GridBagLayout() );
		panel.add( panel1, BorderLayout.CENTER );
		panel1.setBorder( BorderFactory.createTitledBorder( BorderFactory.createEtchedBorder(),
		                                                    "Database Properties" ) );
		final JLabel label1 = new JLabel();
		label1.setFont( new Font( label1.getFont().getName(), Font.BOLD, label1.getFont().getSize() ) );
		label1.setText( "Database Size" );
		GridBagConstraints gbc;
		gbc = new GridBagConstraints();
		gbc.gridx = 0;
		gbc.gridy = 0;
		gbc.anchor = GridBagConstraints.WEST;
		gbc.insets = new Insets( 4, 4, 4, 4 );
		panel1.add( label1, gbc );
		dbSizeLabel = new JLabel();
		dbSizeLabel.setFont(
				new Font( dbSizeLabel.getFont().getName(), Font.PLAIN, dbSizeLabel.getFont().getSize() ) );
		dbSizeLabel.setText( "Label" );
		gbc = new GridBagConstraints();
		gbc.gridx = 1;
		gbc.gridy = 0;
		gbc.weightx = 1.0;
		gbc.anchor = GridBagConstraints.WEST;
		gbc.insets = new Insets( 4, 4, 4, 4 );
		panel1.add( dbSizeLabel, gbc );
		final JLabel label2 = new JLabel();
		label2.setFont( new Font( label2.getFont().getName(), Font.BOLD, label2.getFont().getSize() ) );
		label2.setText( "Block Size" );
		gbc = new GridBagConstraints();
		gbc.gridx = 0;
		gbc.gridy = 1;
		gbc.anchor = GridBagConstraints.WEST;
		gbc.insets = new Insets( 4, 4, 4, 4 );
		panel1.add( label2, gbc );
		blockSizeLabel = new JLabel();
		blockSizeLabel.setFont( new Font( blockSizeLabel.getFont().getName(), Font.PLAIN,
		                                  blockSizeLabel.getFont().getSize() ) );
		blockSizeLabel.setText( "Label" );
		gbc = new GridBagConstraints();
		gbc.gridx = 1;
		gbc.gridy = 1;
		gbc.anchor = GridBagConstraints.WEST;
		gbc.insets = new Insets( 4, 4, 4, 4 );
		panel1.add( blockSizeLabel, gbc );
		final JLabel label3 = new JLabel();
		label3.setFont( new Font( label3.getFont().getName(), Font.BOLD, label3.getFont().getSize() ) );
		label3.setText( "Number of Streams" );
		gbc = new GridBagConstraints();
		gbc.gridx = 0;
		gbc.gridy = 2;
		gbc.anchor = GridBagConstraints.WEST;
		gbc.insets = new Insets( 4, 4, 4, 4 );
		panel1.add( label3, gbc );
		numStreamsLabel = new JLabel();
		numStreamsLabel.setFont( new Font( numStreamsLabel.getFont().getName(), Font.PLAIN,
		                                   numStreamsLabel.getFont().getSize() ) );
		numStreamsLabel.setText( "Label" );
		gbc = new GridBagConstraints();
		gbc.gridx = 1;
		gbc.gridy = 2;
		gbc.anchor = GridBagConstraints.WEST;
		gbc.insets = new Insets( 4, 4, 4, 4 );
		panel1.add( numStreamsLabel, gbc );
		final JLabel label4 = new JLabel();
		label4.setFont( new Font( label4.getFont().getName(), Font.BOLD, label4.getFont().getSize() ) );
		label4.setText( "Data Block Size" );
		gbc = new GridBagConstraints();
		gbc.gridx = 0;
		gbc.gridy = 3;
		gbc.anchor = GridBagConstraints.WEST;
		gbc.insets = new Insets( 4, 4, 4, 4 );
		panel1.add( label4, gbc );
		dataBlockSizeLabel = new JLabel();
		dataBlockSizeLabel.setFont( new Font( dataBlockSizeLabel.getFont().getName(), Font.PLAIN,
		                                      dataBlockSizeLabel.getFont().getSize() ) );
		dataBlockSizeLabel.setText( "Label" );
		gbc = new GridBagConstraints();
		gbc.gridx = 1;
		gbc.gridy = 3;
		gbc.anchor = GridBagConstraints.WEST;
		gbc.insets = new Insets( 4, 4, 4, 4 );
		panel1.add( dataBlockSizeLabel, gbc );
		final JLabel label5 = new JLabel();
		label5.setFont( new Font( label5.getFont().getName(), Font.BOLD, label5.getFont().getSize() ) );
		label5.setText( "Max Streams" );
		gbc = new GridBagConstraints();
		gbc.gridx = 0;
		gbc.gridy = 4;
		gbc.anchor = GridBagConstraints.WEST;
		gbc.insets = new Insets( 4, 4, 4, 4 );
		panel1.add( label5, gbc );
		maxStreamsLabel = new JLabel();
		maxStreamsLabel.setFont( new Font( maxStreamsLabel.getFont().getName(), Font.PLAIN,
		                                   maxStreamsLabel.getFont().getSize() ) );
		maxStreamsLabel.setText( "Label" );
		gbc = new GridBagConstraints();
		gbc.gridx = 1;
		gbc.gridy = 4;
		gbc.anchor = GridBagConstraints.WEST;
		gbc.insets = new Insets( 4, 4, 4, 4 );
		panel1.add( maxStreamsLabel, gbc );
		final JLabel label6 = new JLabel();
		label6.setFont( new Font( label6.getFont().getName(), Font.BOLD, label6.getFont().getSize() ) );
		label6.setText( "Sections" );
		gbc = new GridBagConstraints();
		gbc.gridx = 0;
		gbc.gridy = 6;
		gbc.anchor = GridBagConstraints.WEST;
		gbc.insets = new Insets( 4, 4, 4, 4 );
		panel1.add( label6, gbc );
		final JScrollPane scrollPane1 = new JScrollPane();
		gbc = new GridBagConstraints();
		gbc.gridx = 1;
		gbc.gridy = 6;
		gbc.weightx = 1.0;
		gbc.weighty = 1.0;
		gbc.fill = GridBagConstraints.BOTH;
		gbc.insets = new Insets( 4, 4, 4, 4 );
		panel1.add( scrollPane1, gbc );
		sectionTable = new JTable();
		sectionTable.setEnabled( false );
		scrollPane1.setViewportView( sectionTable );
		final JLabel label7 = new JLabel();
		label7.setFont( new Font( label7.getFont().getName(), Font.BOLD, label7.getFont().getSize() ) );
		label7.setText( "Data Block Usage" );
		gbc = new GridBagConstraints();
		gbc.gridx = 0;
		gbc.gridy = 5;
		gbc.anchor = GridBagConstraints.WEST;
		gbc.insets = new Insets( 4, 4, 4, 4 );
		panel1.add( label7, gbc );
		dataUsageLabel = new JLabel();
		dataUsageLabel.setFont( new Font( dataUsageLabel.getFont().getName(), Font.PLAIN,
		                                  dataUsageLabel.getFont().getSize() ) );
		dataUsageLabel.setText( "Label" );
		gbc = new GridBagConstraints();
		gbc.gridx = 1;
		gbc.gridy = 5;
		gbc.anchor = GridBagConstraints.WEST;
		gbc.insets = new Insets( 4, 4, 4, 4 );
		panel1.add( dataUsageLabel, gbc );
	}

	/**
	 * @noinspection ALL
	 */
	public JComponent $$$getRootComponent$$$() {
		return panel;
	}
}
