/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.tools.gui;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;

/**
 * The BasicModel provides a basic framework for a model that generates events when its properties
 * change. It also provides the concept of an "error" state for when an operation goes wrong.
 *
 * @author Jason Winnebeck
 */
public class DefaultBasicModel implements BasicModel {
	protected final PropertyChangeSupport pcs;

	private ModelError error = null;

	protected DefaultBasicModel() {
		pcs = new PropertyChangeSupport( this );
	}

	protected DefaultBasicModel( PropertyChangeSupport pcs ) {
		this.pcs = pcs;
	}

	public void addPropertyChangeListener( PropertyChangeListener listener ) {
		pcs.addPropertyChangeListener( listener );
	}

	public void removePropertyChangeListener( PropertyChangeListener listener ) {
		pcs.removePropertyChangeListener( listener );
	}

	public void addPropertyChangeListener( String propertyName,
	                                       PropertyChangeListener listener ) {
		pcs.addPropertyChangeListener( propertyName, listener );
	}

	public void removePropertyChangeListener( String propertyName,
	                                          PropertyChangeListener listener ) {
		pcs.removePropertyChangeListener( propertyName, listener );
	}

	public ModelError getError() {
		return error;
	}

	protected DefaultBasicModel setError( ModelError newVal ) {
		ModelError oldVal = error;
		error = newVal;
		pcs.firePropertyChange( "error", oldVal, newVal );
		return this;
	}

	protected DefaultBasicModel setError( String summary, Throwable detail ) {
		return setError( new ModelError( summary, detail ) );
	}
}