/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.tools.gui;

import org.gillius.realdb.model.DataStream;
import org.gillius.realdb.model.Database;

import javax.swing.*;
import java.awt.*;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;

/**
 * DisplayFactory creates displays based on given objects.
 *
 * @author Jason Winnebeck
 */
public class DisplayFactory {

	/**
	 * Makes a display from an arbitrary object.
	 */
	public static JComponent makeDisplay( Object o ) {
		if ( o == null ) {
			return makeEmpty();

		} else if ( o instanceof BrowserController ) {
			return make( (BrowserController) o );

		} else if ( o instanceof DataStream ) {
			return make( (DataStream) o );

		} else if ( o instanceof Database ) {
			return make( (Database) o );

		} else {
			//We don't know what this is...
			return makeEmpty();
		}
	}

	private static JComponent make( DataStream stream ) {
		return new DataStreamView( stream ).getPanel();
	}

	private static JComponent make( Database db ) {
		return new DatabaseView( db ).getPanel();
	}

	public static JComponent makeEmpty() {
		JLabel label = new JLabel( "Please select an element from the tree" );
		JPanel ret = new JPanel( new BorderLayout() );
		ret.add( label, BorderLayout.CENTER );
		return ret;
	}

	public static JComponent make( final BrowserController ctl ) {
		DatabaseSelectionImpl model = new DatabaseSelectionImpl();
		DatabaseSelectionView view = new DatabaseSelectionView(
				model, SchedulingProxy.create( DatabaseSelectionController.class, model ) );

		model.addPropertyChangeListener( SwingProxy.create( new PropertyChangeListener() {
			public void propertyChange( PropertyChangeEvent evt ) {
				if ( evt.getPropertyName().equals( "database" ) ) {
					ctl.setTreeRoot( DatabaseTreeBuilder.build( (Database) evt.getNewValue() ) );
				}
			}
		} ) );

		return view.getPanel();
	}
}
