/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.tools.gui;

import javax.swing.*;
import java.awt.*;
import java.io.PrintWriter;
import java.io.StringWriter;

/**
 * ErrorDialog is a document-modal dialog displaying an error message.
 *
 * @author Jason Winnebeck
 */
public class ErrorDialog extends JDialog {
	private JPanel contentPane;
	private JLabel errorSummary;
	private JTextArea errorDetail;

	public ErrorDialog( Window owner ) {
		super( owner );
		setContentPane( contentPane );

		setTitle( "Error" );
		setModalityType( ModalityType.DOCUMENT_MODAL );
	}

	@SuppressWarnings( { "ThrowableResultOfMethodCallIgnored" } )
	public void setError( ModelError error ) {
		errorSummary.setText( error.getSummary() );

		if ( error.getDetail() != null ) {
			StringWriter str = new StringWriter( 512 );
			PrintWriter writer = new PrintWriter( str );
			error.getDetail().printStackTrace( writer );
			errorDetail.setText( str.toString() );
		}
	}

	/**
	 * Show an ErrorDialog on the given component if the error given is not null. This method must be
	 * called from the event thread.
	 */
	public static void show( ModelError err, Component component ) {
		if ( err != null ) {
			ErrorDialog dlg = new ErrorDialog( SwingUtilities.getWindowAncestor( component ) );
			dlg.setError( err );
			dlg.pack();
			dlg.setLocationRelativeTo( component );
			dlg.setVisible( true );
		}
	}

	{
// GUI initializer generated by IntelliJ IDEA GUI Designer
// >>> IMPORTANT!! <<<
// DO NOT EDIT OR ADD ANY CODE HERE!
		$$$setupUI$$$();
	}

	/**
	 * Method generated by IntelliJ IDEA GUI Designer >>> IMPORTANT!! <<< DO NOT edit this method OR
	 * call it in your code!
	 *
	 * @noinspection ALL
	 */
	private void $$$setupUI$$$() {
		contentPane = new JPanel();
		contentPane.setLayout( new GridBagLayout() );
		final JLabel label1 = new JLabel();
		label1.setFont( new Font( label1.getFont().getName(), Font.BOLD, label1.getFont().getSize() ) );
		label1.setText( "An error has occurred in the application" );
		GridBagConstraints gbc;
		gbc = new GridBagConstraints();
		gbc.gridx = 0;
		gbc.gridy = 0;
		gbc.gridwidth = 2;
		gbc.anchor = GridBagConstraints.WEST;
		gbc.insets = new Insets( 8, 8, 8, 8 );
		contentPane.add( label1, gbc );
		final JLabel label2 = new JLabel();
		label2.setFont( new Font( label2.getFont().getName(), Font.BOLD, label2.getFont().getSize() ) );
		label2.setText( "Error Summary" );
		gbc = new GridBagConstraints();
		gbc.gridx = 0;
		gbc.gridy = 1;
		gbc.anchor = GridBagConstraints.WEST;
		gbc.insets = new Insets( 8, 8, 8, 8 );
		contentPane.add( label2, gbc );
		errorSummary = new JLabel();
		errorSummary.setText( "summary" );
		gbc = new GridBagConstraints();
		gbc.gridx = 1;
		gbc.gridy = 1;
		gbc.anchor = GridBagConstraints.WEST;
		gbc.insets = new Insets( 8, 8, 8, 8 );
		contentPane.add( errorSummary, gbc );
		final JLabel label3 = new JLabel();
		label3.setFont( new Font( label3.getFont().getName(), Font.BOLD, label3.getFont().getSize() ) );
		label3.setText( "Error Detail" );
		gbc = new GridBagConstraints();
		gbc.gridx = 0;
		gbc.gridy = 2;
		gbc.anchor = GridBagConstraints.NORTHWEST;
		gbc.insets = new Insets( 8, 8, 8, 8 );
		contentPane.add( label3, gbc );
		final JScrollPane scrollPane1 = new JScrollPane();
		gbc = new GridBagConstraints();
		gbc.gridx = 1;
		gbc.gridy = 2;
		gbc.weightx = 1.0;
		gbc.weighty = 1.0;
		gbc.fill = GridBagConstraints.BOTH;
		gbc.insets = new Insets( 8, 8, 8, 8 );
		contentPane.add( scrollPane1, gbc );
		errorDetail = new JTextArea();
		errorDetail.setEditable( false );
		scrollPane1.setViewportView( errorDetail );
	}

	/**
	 * @noinspection ALL
	 */
	public JComponent $$$getRootComponent$$$() {
		return contentPane;
	}
}
