/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.tools.gui;

import org.gillius.realdb.metadata.RecordElement;
import org.gillius.realdb.model.data.Record;

import javax.swing.event.TableModelEvent;
import javax.swing.event.TableModelListener;
import java.util.List;
import java.util.concurrent.CopyOnWriteArrayList;

/**
 * RecordsTableModel implements a fixed-content {@link RowTableModel} of {@link Record}.
 *
 * @author Jason Winnebeck
 */
public class RecordsTableModel implements RowTableModel<Record> {
	private final RecordElement[] elements;
	private List<Record> records;

	private final CopyOnWriteArrayList<TableModelListener> listeners;

	public RecordsTableModel( RecordElement[] elements, List<Record> records ) {
		this.elements = elements;
		this.records = records;

		listeners = new CopyOnWriteArrayList<TableModelListener>();
	}

	@Override
	public Record getRow( int rowIndex ) {
		return records.get( rowIndex );
	}

	public void setRows( List<Record> rows ) {
		records = rows;
		if ( !listeners.isEmpty() ) {
			TableModelEvent event = new TableModelEvent( this );
			for ( TableModelListener listener : listeners ) {
				listener.tableChanged( event );
			}
		}
	}

	@Override
	public int getRowCount() {
		return records.size();
	}

	@Override
	public int getColumnCount() {
		return elements.length + 1;
	}

	@Override
	public String getColumnName( int columnIndex ) {
		if ( columnIndex == 0 )
			return "time";
		else
			return elements[ columnIndex-1 ].getName();
	}

	@Override
	public Class<?> getColumnClass( int columnIndex ) {
		if ( columnIndex == 0 )
			return Long.class;
		else
			return elements[ columnIndex-1 ].getType().getTypeClass();
	}

	@Override
	public boolean isCellEditable( int rowIndex, int columnIndex ) {
		return false;
	}

	@Override
	public Object getValueAt( int rowIndex, int columnIndex ) {
		Record row = getRow( rowIndex );
		if ( columnIndex == 0 )
			return row.getTime();
		else
			return row.isDiscontinuity() ? null : row.getElement( columnIndex - 1 );
	}

	@Override
	public void setValueAt( Object aValue, int rowIndex, int columnIndex ) {
	}

	@Override
	public void addTableModelListener( TableModelListener l ) {
		listeners.add( l );
	}

	@Override
	public void removeTableModelListener( TableModelListener l ) {
		listeners.remove( l );
	}
}
