/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.tools.gui;

import javax.swing.*;
import javax.swing.event.ListSelectionEvent;
import javax.swing.event.ListSelectionListener;

/**
 * RowTableSelectionListener adapts a JTable with a {@link RowTableModel} to a
 * {@link SelectionModel} such that when a row is selected in the table it is set in the
 * SelectionModel.
 *
 * @author Jason Winnebeck
 */
public class RowTableSelectionListener<T> implements ListSelectionListener {
	private final JTable table;
	private final SelectionModel<T> model;

	/**
	 * Constructs the listener, which should be registered on the given table's ListSelectionModel.
	 */
	public RowTableSelectionListener( JTable table, SelectionModel<T> model ) {
		this.table = table;
		this.model = model;
	}

	@Override
	public void valueChanged( ListSelectionEvent e ) {
		if ( !e.getValueIsAdjusting() ) {
			int recordIndex = table.convertRowIndexToModel( table.getSelectedRow() );
			model.setSelected( ((RowTableModel<T>)table.getModel()).getRow( recordIndex ) );
		}
	}
}
