/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.tools.gui;

import org.gillius.realdb.metadata.RecordElement;
import org.gillius.realdb.model.data.StreamInterval;

import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;
import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.CopyOnWriteArrayList;

/**
 * StreamIntervalsModelImpl
 *
 * @author Jason Winnebeck
 */
public class StreamIntervalsModelImpl implements StreamIntervalsModel {
	private RecordElement[] elements;
	private List<StreamInterval> data;

	private final CopyOnWriteArrayList<ChangeListener> changeListeners;

	public StreamIntervalsModelImpl( RecordElement[] elements, List<StreamInterval> data ) {
		this.elements = elements;
		this.data = data;

		changeListeners = new CopyOnWriteArrayList<ChangeListener>();
	}

	@Override
	public void addChangeListener( ChangeListener l ) {
		changeListeners.add( l );
	}

	@Override
	public void removeChangeListener( ChangeListener l ) {
		changeListeners.remove( l );
	}

	public void setRows( List<StreamInterval> rows ) {
		data = new ArrayList<StreamInterval>( rows );

		if ( !changeListeners.isEmpty() ) {
			ChangeEvent event = new ChangeEvent( this );
			for ( ChangeListener listener : changeListeners ) {
				listener.stateChanged( event );
			}
		}
	}

	@Override
	public StreamInterval getRow( int rowIndex ) {
		return data.get( rowIndex );
	}

	@Override
	public RecordElement[] getElements() {
		return elements;
	}

	@Override
	public int getRowCount() {
		return data.size();
	}
}
