/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.tools.cli;

import org.gillius.realdb.model.data.UnsignedByte;
import org.gillius.realdb.model.data.UnsignedInteger;
import org.gillius.realdb.model.data.UnsignedShort;

import java.io.File;

/**
 * Converter provides a method to convert a String into an Object of a requested type.
 *
 * @author Jason Winnebeck
 */
@SuppressWarnings( { "unchecked" } )
public class Converter {

	public static <T> T convert( Class<T> type, String s ) throws IllegalArgumentException {
		if ( "null".equalsIgnoreCase( s ) )
			return null;

		if ( type == File.class ) {
			return (T) new File( s );
		} else if ( type == String.class ) {
			return (T) s;
		} else if ( type == Byte.class ) {
			return (T) Byte.decode( s );
		} else if ( type == Short.class ) {
			return (T) Short.decode( s );
		} else if ( type == Integer.class ) {
			return (T) Integer.decode( s );
		} else if ( type == Long.class ) {
			return (T) Long.decode( s );
		} else if ( type == UnsignedByte.class ) {
			return (T) new UnsignedByte( Integer.decode( s ) );
		} else if ( type == UnsignedShort.class ) {
			return (T) new UnsignedShort( Integer.decode( s ) );
		} else if ( type == UnsignedInteger.class ) {
			return (T) new UnsignedInteger( Long.decode( s ) );
		} else if ( type == Float.class ) {
			return (T) new Float( s );
		} else if ( type == Double.class ) {
			return (T) new Double( s );
		} else if ( type == Boolean.class ) {
			return (T) ( ( "1".equals( s ) || "true".equalsIgnoreCase( s ) ) ? Boolean.TRUE : Boolean.FALSE );
		} else {
			throw new IllegalArgumentException( "Unknown type for conversion: " + type );
		}
	}
}
