/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.tools.cli;

import org.gillius.realdb.BadFileException;
import org.gillius.realdb.io.rdl.RDLFile;
import org.gillius.realdb.tools.DatabaseBuilder;

import java.io.File;
import java.io.IOException;
import java.util.List;

import static java.util.Arrays.*;
import static java.util.Collections.*;

/**
 * CreateDatabaseCommand is a command that can create a new RealDB database from an RDL file.
 *
 * @author Jason Winnebeck
 */
public class CreateDatabaseCommand extends AbstractCommand {
	private static final List<Parameter> params = unmodifiableList( asList(
			new Parameter( "RDL File", File.class, true, "RealDB Definition Language file" ),
			new Parameter( "Database", File.class, true, "Database file to create" ) ) );

	public String getName() {
		return "create";
	}

	public String getHelpText() {
		return "Creates a new RealDB Database";
	}

	public List<Parameter> getParameters() {
		return params;
	}

	public void executeValidated( ExecutionContext context, Object[] params ) throws CommandException {
		File rdlPath = (File) params[0];
		File output  = (File) params[1];

		if ( !rdlPath.isFile() )
			throw new CommandException( rdlPath.getAbsolutePath() + " does not exist or is not a file." );

		try {
			RDLFile rdl = RDLFile.loadFile( rdlPath );
			DatabaseBuilder builder = new DatabaseBuilder( rdl );
			builder.createDatabase( output ).close();
			context.getOutput().println( "Created database at " + output );

		} catch ( IOException e ) {
			throw new CommandException( e );
		} catch ( BadFileException e ) {
			throw new CommandException( e );
		}
	}
}
