/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.tools.cli;

import junit.framework.TestCase;
import org.gillius.Util.IOUtils;
import org.gillius.realdb.model.Database;

import java.io.File;
import java.io.PrintWriter;

/**
 * TestCreateDatabaseCommand tests the {@link CreateDatabaseCommand}.
 *
 * @author Jason Winnebeck
 */
public class TestCreateDatabaseCommand extends TestCase {

	private static final String RDL_CONTENT =
			"SET blockSize     = 2048 " +
			"SET fileSize      = 204800 " +
			"SET maxStreams    = 3 " +
			"SET dataBlockSize = 2 " +
			"CREATE STREAM Test WITH ID 1 {value float WITH CODEC SampledAlgorithm}";

	public void testCreate() throws Exception {
		File rdl = null;
		File db  = null;
		try {
			rdl = File.createTempFile( "TestCreateDatabaseCommand", ".rdl" );
			db  = File.createTempFile( "TestCreateDatabaseCommand", ".rdb" );

			PrintWriter out = new PrintWriter( rdl );
			out.print( RDL_CONTENT );
			out.close();

			IOUtils.safeDelete( db );
			CreateDatabaseCommand c = new CreateDatabaseCommand();
			ExecutionContext context = new DefaultExecutionContext( System.out, System.err );

			c.execute( context, new Object[] { rdl, db } );

			assertTrue( db.isFile() );
			assertEquals( 204800, db.length() );

			Database database = Database.load( db );
			assertEquals( 3, database.getMetadata().getMaxStreams() );
			assertEquals( 2, database.getMetadata().getDataBlockSize() );

		} finally {
			IOUtils.safeDelete( rdl );
			IOUtils.safeDelete( db );
		}
	}
}