/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.concept;

import org.gillius.realdb.model.Database;
import org.gillius.realdb.tools.gui.DatabaseSelectionImpl;
import org.gillius.realdb.tools.gui.DatabaseSelectionView;
import org.gillius.realdb.tools.gui.SwingProxy;

import javax.swing.*;
import java.awt.*;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;

/**
 * AnalysisDemo runs a graphical UI-based application to analyze the event data generated by
 * {@link VehicleDataSimulation}.
 *
 * @author Jason Winnebeck
 */
public class AnalysisDemo {
	public static void main( String[] args ) {
		final AnalysisModelImpl model = new AnalysisModelImpl();
		final DatabaseSelectionImpl dbModel = new DatabaseSelectionImpl();

		dbModel.addPropertyChangeListener( new PropertyChangeListener() {
			@Override
			public void propertyChange( PropertyChangeEvent evt ) {
				if ( "database".equals( evt.getPropertyName() ) )
					model.setDatabase( (Database) evt.getNewValue() );
			}
		} );

		SwingUtilities.invokeLater( new Runnable() {
			public void run() {
				AnalysisView view = new AnalysisView( model );

				JFrame frame = new JFrame( "Milestone 5 RealDB Concept Demo" );
				frame.setDefaultCloseOperation( JFrame.EXIT_ON_CLOSE );
				frame.setContentPane( view.getPanel() );
				frame.pack();
				frame.setLocationByPlatform( true );
				frame.setVisible( true );

				DatabaseSelectionView selectionView = new DatabaseSelectionView( dbModel, dbModel );

				final JDialog selectDlg = new JDialog( frame, "Select Database",
				                                       Dialog.ModalityType.DOCUMENT_MODAL );

				dbModel.addPropertyChangeListener( SwingProxy.create( new PropertyChangeListener() {
					@Override
					public void propertyChange( PropertyChangeEvent evt ) {
						if ( "database".equals( evt.getPropertyName() ) )
							selectDlg.dispose();
					}
				} ));
				selectDlg.setDefaultCloseOperation( JFrame.DISPOSE_ON_CLOSE );
				selectDlg.setContentPane( selectionView.getPanel() );
				selectDlg.pack();
				selectDlg.setLocationRelativeTo( frame );
				selectDlg.setVisible( true );
			}
		} );
	}
}
