/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.concept;

import org.gillius.realdb.model.data.StreamInterval;
import org.gillius.realdb.tools.gui.ChartRecordsView;
import org.gillius.realdb.tools.gui.RowTableSelectionListener;
import org.gillius.realdb.tools.gui.SelectionModel;
import org.gillius.realdb.tools.gui.StreamIntervalsModel;
import org.gillius.realdb.tools.gui.SwingProxy;

import javax.swing.*;
import javax.swing.table.TableModel;
import java.awt.*;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.util.Collection;
import java.util.Vector;

/**
 * AnalysisView
 *
 * @author Jason Winnebeck
 */
public class AnalysisView {
	private JPanel panel;
	private JTable incidentsTable;
	private JComboBox streamCombo;
	private ChartRecordsView chartView;

	public AnalysisView( AnalysisModel model ) {
		final SelectionModel<Object> selectedSource = model.getSelectedSourceModel();
		model.addPropertyChangeListener( SwingProxy.create( new PropertyChangeListener() {
			@Override
			public void propertyChange( PropertyChangeEvent evt ) {
				if ( "incidents".equals( evt.getPropertyName() ) ) {
					incidentsTable.setModel( (TableModel) evt.getNewValue() );

				} else if ( "chartData".equals( evt.getPropertyName() ) ) {
					chartView.setModel( (StreamIntervalsModel) evt.getNewValue() );

				} else if ( "chartDataSources".equals( evt.getPropertyName() ) ) {
					streamCombo.setModel( new DefaultComboBoxModel(
							new Vector<Object>( (Collection<Object>) evt.getNewValue() ) ) );
					//Setting the model doesn't seem to fire an item event.
					selectedSource.setSelected( streamCombo.getSelectedItem() );
				}
			}
		} ) );

		SelectionModel<StreamInterval> selectedEvent = model.getSelectedIncidentModel();

		incidentsTable.getSelectionModel().addListSelectionListener(
				new RowTableSelectionListener( incidentsTable, selectedEvent ) );
		incidentsTable.getSelectionModel().setSelectionMode( ListSelectionModel.SINGLE_SELECTION );

		streamCombo.setModel( new DefaultComboBoxModel( new Vector<Object>( model.getChartDataSources() ) ) );

		streamCombo.addItemListener( new ItemListener() {
			@Override
			public void itemStateChanged( ItemEvent e ) {
				if ( e.getStateChange() == ItemEvent.SELECTED ) {
					selectedSource.setSelected( streamCombo.getSelectedItem() );
				}
			}
		} );

		incidentsTable.setModel( model.getIncidents() );
	}

	public JPanel getPanel() {
		return panel;
	}

	{
// GUI initializer generated by IntelliJ IDEA GUI Designer
// >>> IMPORTANT!! <<<
// DO NOT EDIT OR ADD ANY CODE HERE!
		$$$setupUI$$$();
	}

	/**
	 * Method generated by IntelliJ IDEA GUI Designer >>> IMPORTANT!! <<< DO NOT edit this method OR
	 * call it in your code!
	 *
	 * @noinspection ALL
	 */
	private void $$$setupUI$$$() {
		panel = new JPanel();
		panel.setLayout( new GridBagLayout() );
		final JPanel panel1 = new JPanel();
		panel1.setLayout( new BorderLayout( 8, 8 ) );
		GridBagConstraints gbc;
		gbc = new GridBagConstraints();
		gbc.gridx = 0;
		gbc.gridy = 0;
		gbc.weightx = 0.333;
		gbc.weighty = 1.0;
		gbc.fill = GridBagConstraints.BOTH;
		gbc.insets = new Insets( 8, 8, 8, 8 );
		panel.add( panel1, gbc );
		final JLabel label1 = new JLabel();
		label1.setText( "Select an incident" );
		panel1.add( label1, BorderLayout.NORTH );
		final JScrollPane scrollPane1 = new JScrollPane();
		panel1.add( scrollPane1, BorderLayout.CENTER );
		incidentsTable = new JTable();
		incidentsTable.setAutoCreateRowSorter( true );
		scrollPane1.setViewportView( incidentsTable );
		final JPanel panel2 = new JPanel();
		panel2.setLayout( new BorderLayout( 8, 8 ) );
		gbc = new GridBagConstraints();
		gbc.gridx = 1;
		gbc.gridy = 0;
		gbc.weightx = 0.667;
		gbc.fill = GridBagConstraints.BOTH;
		gbc.insets = new Insets( 8, 8, 8, 8 );
		panel.add( panel2, gbc );
		final JPanel panel3 = new JPanel();
		panel3.setLayout( new FlowLayout( FlowLayout.CENTER, 5, 5 ) );
		panel2.add( panel3, BorderLayout.NORTH );
		final JLabel label2 = new JLabel();
		label2.setText( "Select a stream" );
		panel3.add( label2 );
		streamCombo = new JComboBox();
		panel3.add( streamCombo );
		chartView = new ChartRecordsView();
		panel2.add( chartView.$$$getRootComponent$$$(), BorderLayout.CENTER );
	}

	/**
	 * @noinspection ALL
	 */
	public JComponent $$$getRootComponent$$$() {
		return panel;
	}
}
