/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.concept;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.nio.ByteBuffer;
import java.nio.channels.Channels;
import java.nio.channels.ReadableByteChannel;
import java.nio.channels.WritableByteChannel;

/**
 * IOUtils contains useful IO utility methods.
 *
 * @author Jason Winnebeck
 */
public class IOUtils {
	/**
	 * Copies all of the content from the input stream to the output stream. The input stream is
	 * closed, but not the output stream.
	 * <p/>
	 * Based on code found at
	 * http://thomaswabner.wordpress.com/2007/10/09/fast-stream-copy-using-javanio-channels/<br>
	 * RealDB copyright does not apply to this method.
	 */
	public static void copy( InputStream in, OutputStream out ) throws IOException {
		// get an channel from the stream
		final ReadableByteChannel inputChannel = Channels.newChannel( in );
		final WritableByteChannel outputChannel = Channels.newChannel( out );
		// copy the channels
		copy( inputChannel, outputChannel );
		// closing the channels
		inputChannel.close();
	}

	/**
	 * Copies all of the content from the source to the destination.
	 * <p/>
	 * Based on code found at
	 * http://thomaswabner.wordpress.com/2007/10/09/fast-stream-copy-using-javanio-channels/<br>
	 * RealDB copyright does not apply to this method.
	 */
	public static void copy( ReadableByteChannel src, WritableByteChannel dest )
			throws IOException {

		final ByteBuffer buffer = ByteBuffer.allocateDirect( 16 * 1024 );
		while ( src.read( buffer ) != -1 ) {
			// prepare the buffer to be drained
			buffer.flip();
			// write to the channel, may block
			dest.write( buffer );
			// If partial transfer, shift remainder down
			// If buffer is empty, same as doing clear()
			buffer.compact();
		}
		// EOF will leave buffer in fill state
		buffer.flip();
		// make sure the buffer is fully drained.
		while ( buffer.hasRemaining() ) {
			dest.write( buffer );
		}
	}
}
