/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.concept;

import org.gillius.realdb.model.data.StreamInterval;
import org.gillius.realdb.tools.gui.RowTableModel;

import javax.swing.event.TableModelListener;
import java.util.List;

/**
 * IncidentsTableModel
 *
 * @author Jason Winnebeck
 */
public class IncidentsTableModel implements RowTableModel<StreamInterval> {
	private List<StreamInterval> rows;

	public IncidentsTableModel( List<StreamInterval> rows ) {
		this.rows = rows;
	}

	@Override
	public StreamInterval getRow( int rowIndex ) {
		return rows.get( rowIndex );
	}

	@Override
	public int getRowCount() {
		return rows.size();
	}

	@Override
	public int getColumnCount() {
		return 3;
	}

	@Override
	public String getColumnName( int columnIndex ) {
		if ( columnIndex == 0 )
			return "Start";
		else if ( columnIndex == 1 )
			return "End";
		else if ( columnIndex == 2 )
			return "Duration";
		else
			throw new IndexOutOfBoundsException( "" + columnIndex );
	}

	@Override
	public Class<?> getColumnClass( int columnIndex ) {
		return Long.class;
	}

	@Override
	public boolean isCellEditable( int rowIndex, int columnIndex ) {
		return false;
	}

	@Override
	public Object getValueAt( int rowIndex, int columnIndex ) {
		if ( columnIndex == 0 )
			return rows.get( rowIndex ).getStartTime();
		else if ( columnIndex == 1 )
			return rows.get( rowIndex ).getEndTime();
		else if ( columnIndex == 2 )
			return rows.get( rowIndex ).getTimespan();
		else
			throw new IndexOutOfBoundsException( "" + columnIndex );
	}

	@Override
	public void setValueAt( Object aValue, int rowIndex, int columnIndex ) {
	}

	@Override
	public void addTableModelListener( TableModelListener l ) {
	}

	@Override
	public void removeTableModelListener( TableModelListener l ) {
	}
}
