/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.concept;

import java.text.NumberFormat;

/**
 * ProgressReporter is a ProgressListener that reports to standard output the total progress.
 *
 * @author Jason Winnebeck
 */
public class ProgressReporter implements ProgressListener {
	private final String units;
	private long total;

	public ProgressReporter( String units ) {
		this.units = units;
	}

	@Override
	public void setTotal( long total ) {
		this.total = total;
	}

	@Override
	public void updatedProgress( long progress ) {
		NumberFormat formatter = NumberFormat.getPercentInstance();
		System.out.format ( "%d %s of %d (%s) processed%n",
		                    progress, units, total, formatter.format( progress / (double) total ) );
	}
}
