/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.concept;

import org.gillius.realdb.BadFileException;
import org.gillius.realdb.model.data.Record;

import java.io.IOException;

/**
 * RecordSink is a destination of {@link Record} objects.
 *
 * @author Jason Winnebeck
 */
public interface RecordSink {
	/**
	 * Writes the given record to this sink.
	 *
	 * @param r non-null Record with a time greater than all previously written records.
	 *
	 * @return true if a Record was physically written, false if the record was removed.
	 *
	 * @throws IOException              If there is an error writing to the sink
	 * @throws BadFileException         If the database is corrupted
	 * @throws IllegalArgumentException If the time for this record is before the last record written
	 *                                  (out-of-order write), or if the record is not appropriate for
	 *                                  this sink.
	 */
	public boolean writeRecord( Record r ) throws IOException, BadFileException;
}
