/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.concept;

import org.gillius.realdb.model.data.GenericRecord;
import org.gillius.realdb.model.data.Record;

/**
 * SingleFieldRecord is a {@link Record} with a single element. It has better performance than
 * {@link GenericRecord} for this situation.
 *
 * @author Jason Winnebeck
 */
public class SingleFieldRecord<T> implements Record {
	private final long time;
	private final T value;

	SingleFieldRecord( long time, T value ) {
		this.time = time;
		this.value = value;
	}

	@Override
	public long getTime() {
		return time;
	}

	@Override
	public boolean isDiscontinuity() {
		return false;
	}

	@Override
	public int getNumElements() {
		return 1;
	}

	@Override
	public Object getElement( int index ) {
		if ( index != 0 )
			throw new IndexOutOfBoundsException( String.valueOf( index ) );

		return value;
	}

	@Override
	public String toString() {
		return "SingleFieldRecord{" +
		       "time=" + time +
		       ", value=" + value +
		       '}';
	}

	@Override
	public boolean equals( Object o ) {
		if ( this == o ) return true;
		if ( o == null || getClass() != o.getClass() ) return false;

		SingleFieldRecord that = (SingleFieldRecord) o;

		if ( time != that.time ) return false;
		if ( value != null ? !value.equals( that.value ) : that.value != null ) return false;

		return true;
	}

	@Override
	public int hashCode() {
		int result = (int) ( time ^ ( time >>> 32 ) );
		result = 31 * result + ( value != null ? value.hashCode() : 0 );
		return result;
	}
}
