/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.concept.data;

import java.io.DataInputStream;
import java.io.EOFException;
import java.io.IOException;
import java.io.InputStream;

/**
 * BinaryVehicleDataParser parses files written by the {@link BinaryWriterVehicleDataHandler}.
 *
 * @author Jason Winnebeck
 */
public class BinaryVehicleDataParser extends AbstractVehicleDataParser {
	private final DataInputStream in;

	public BinaryVehicleDataParser( InputStream in ) {
		this.in = new DataInputStream( in );
	}

	@SuppressWarnings( { "InfiniteLoopStatement" } )
	@Override
	public void parse() throws IOException, DataHandlingException {
		if ( handler == null )
			throw new IllegalStateException( "No handler set" );

		handler.startStream();
		try {
			while ( true ) {
				int     stream        = in.readInt    ();
				long    time          = in.readLong   ();
				float   value         = in.readFloat  ();
				boolean discontinuity = in.readBoolean();

				handler.dataRead( stream, time, value, discontinuity );
			}
		} catch ( EOFException e ) {
			//we're done. There's no method of DataInput that will let us find out if we are at EOF
		} finally {
			in.close();
			handler.endStream();
		}
	}
}
