/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.concept.data;

import java.io.BufferedOutputStream;
import java.io.BufferedReader;
import java.io.DataOutputStream;
import java.io.FileOutputStream;
import java.io.FileReader;
import java.io.Reader;

/**
 * TextToBinaryConverter is a program taking two arguments, an input and output file and converts
 * the input text file to a binary file. The text file format is described in
 * {@link TextVehicleDataParser} and the binary format in {@link BinaryWriterVehicleDataHandler}.
 * The delimiter used is a single comma.
 *
 * @author Jason Winnebeck
 */
public class TextToBinaryConverter {
	public static void main( String[] args ) throws Exception {
		if ( args.length != 2 ) {
			System.err.println( "Need 2 arguments: input text file and output binary file" );
			System.exit( 1 );
		}

		Reader reader = new BufferedReader( new FileReader( args[0] ) );
		VehicleDataParser parser = new TextVehicleDataParser( reader, "," );
		DataOutputStream output =
				new DataOutputStream( new BufferedOutputStream( new FileOutputStream( args[1] ) ) );
		parser.setHandler( new BinaryWriterVehicleDataHandler( output ) );

		parser.parse();
		output.close();
		reader.close();
	}
}
