/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.concept.data;

/**
 * VehicleDataHandler handles rows of raw vehicle data, used as the data source in the concept. This
 * interface and the primary implementations of this and related APIs are designed to be memory
 * allocation-free if possible for speed. As a result they are also less flexible.
 *
 * @author Jason Winnebeck
 */
public interface VehicleDataHandler {
	/**
	 * Event called when stream processing begins.
	 */
	public void startStream() throws DataHandlingException;

	/**
	 * Data read event for floating point data. Data is passed into the handler in order of time.
	 *
	 * @param stream        stream ID
	 * @param time          data point time
	 * @param value         data point value
	 * @param discontinuity is this point a discontinuity? if so, value is undefined.
	 */
	public void dataRead( int stream, long time, float value, boolean discontinuity )
			throws DataHandlingException;

	/**
	 * Data read event for boolean data. Data is passed into the handler in order of time.
	 *
	 * @param stream        stream ID
	 * @param time          data point time
	 * @param value         data point value
	 * @param discontinuity is this point a discontinuity? if so, value is undefined.
	 */
	public void dataRead( int stream, long time, boolean value, boolean discontinuity )
			throws DataHandlingException;

	/**
	 * Event called when stream processing ends.
	 */
	public void endStream() throws DataHandlingException;
}
