/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.concept.data;

import java.io.IOException;

/**
 * VehicleDataParser is a source of events for a {@link VehicleDataHandler}. Some implementations
 * can only parse their data source a single time.
 *
 * @author Jason Winnebeck
 */
public interface VehicleDataParser {
	VehicleDataHandler getHandler();

	void setHandler( VehicleDataHandler handler );

	/**
	 * Parses the entire data source for vehicle data. If there is an underlying IO stream of file
	 * for this parser, it is closed at the end of this method.
	 *
	 * @throws IOException           if there is an error reading the data source
	 * @throws DataHandlingException if there is an error from the {@link VehicleDataHandler}, or if
	 *                               the data can be read but not parsed.
	 */
	void parse() throws IOException, DataHandlingException;
}
