/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.concept;

import org.easymock.*;
import org.gillius.realdb.model.data.Discontinuity;
import org.gillius.realdb.model.data.Record;
import org.junit.*;

import java.util.HashMap;
import java.util.Map;

import static org.easymock.EasyMock.*;

/**
 * TestRecordSinkWritingHandler tests the {@link RecordSinkWritingHandler}.
 *
 * @author Jason Winnebeck
 */
public class TestRecordSinkWritingHandler extends EasyMockSupport {
	private Map<Integer, RecordSink> sinks;

	private RecordSinkWritingHandler handler;

	@Before
	public void setUp() {
		sinks = new HashMap<Integer, RecordSink>();

		sinks.put( 1, createNiceMock( "stream" + 1, RecordSink.class ) );
		sinks.put( 2, createNiceMock( "stream" + 2, RecordSink.class ) );

		handler = new RecordSinkWritingHandler( sinks );
	}

	@Test
	public void testDiscontinuity() throws Exception {
		resetAll();
		expectDiscontinuity( 1, 100 );
		expectDiscontinuity( 2, 200 );
		replayAll();

		handler.dataRead( 1, 100, 23.0f, true );
		handler.dataRead( 2, 200, true, true );

		verifyAll();
	}

	@Test
	public void testWrites() throws Exception {
		resetAll();
		expectFloat( 1, 100, 23.0f );
		expectBool( 2, 200, true );
		replayAll();

		handler.dataRead( 1, 100, 23.0f, false );
		handler.dataRead( 2, 200, true, false );

		verifyAll();
	}

	private void expectDiscontinuity( int stream, long time ) throws Exception {
		expect( sinks.get( stream ).writeRecord( new Discontinuity( time ) ) ).andReturn( true );
	}

	private void expectFloat( int stream, long time, float value ) throws Exception {
		Record r = new SingleFieldRecord<Float>( time, value );
		expect( sinks.get( stream ).writeRecord( r ) ).andReturn( true );
	}

	private void expectBool( int stream, long time, boolean value ) throws Exception {
		Record r = new SingleFieldRecord<Boolean>( time, value );
		expect( sinks.get( stream ).writeRecord( r ) ).andReturn( true );
	}
}
