/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.concept.data;

import org.junit.*;

import java.io.StringReader;

import static org.easymock.EasyMock.*;

/**
 * TestTextVehicleDataParser is a light test for the {@link TextVehicleDataParser} that only tests
 * a "good" data input.
 *
 * @author Jason Winnebeck
 */
public class TestTextVehicleDataParser {
	@Test
	public void testParse() throws Exception {
		String data = "1 345 10.5 0\n"+
	                "2 999 0 1";

		TextVehicleDataParser parser = new TextVehicleDataParser( new StringReader( data ), " " );

		VehicleDataHandler handler = createStrictMock( VehicleDataHandler.class );
		handler.startStream();
		handler.dataRead( 1, 345, 10.5f, false );
		handler.dataRead( 2, 999, 0.0f, true );
		handler.endStream();
		replay( handler );

		parser.setHandler( handler );
		parser.parse();

		verify( handler );
	}
}
