grammar RDBDefinition;

tokens {
	EQ = '=' ;
	QUOTE = '"' ;
	OPEN_BLOCK = '{' ;
	CLOSE_BLOCK = '}' ;
	OPEN_PAREN = '(' ;
	CLOSE_PAREN = ')' ;
	COMMA = ','; //element separator
}

@lexer::header {
package org.gillius.realdb.io.rdl;
}

@header {
package org.gillius.realdb.io.rdl;
}

@members {
private RDLFile file;

public void emitErrorMessage( String err ) {
  file.reportError( err );
}
}

/*------------------------------------------------------------------
 * PARSER RULES
 *------------------------------------------------------------------*/

statements returns [RDLFile f]
	:	{file=new RDLFile();} ( setStatement | createStatement )+ EOF {$f = file;};

setStatement
	:	SET name=IDENTIFIER EQ value
		{file.addOption( $name.text, $value.text );};

//TODO: need to allow setting of description
createStatement
	:	CREATE STREAM name=string WITHID id=INTEGER OPEN_BLOCK (recordElement COMMA)* recordElement CLOSE_BLOCK
		{file.addStream( $name.text, $id.text ); } ;

recordElement
	:	name=IDENTIFIER type n=NULL? (WITHCODEC codec=IDENTIFIER params?)?
		{file.addElement( $name.text, $type.text, $n != null, $codec.text ); };

params
	:	PARAMS OPEN_PAREN (name=IDENTIFIER EQ value)+ CLOSE_PAREN
		{file.addCodecParam( $name.text, $value.text ); } ;

type	:	SINT8 | SINT16 | SINT32 | SINT64 | UINT8 | UINT16 | UINT32 | FLOAT | DOUBLE | BOOLEAN ;

value	:	string | INTEGER | NUMBER;

string	:	QUOTED_STRING | IDENTIFIER ;

/*------------------------------------------------------------------
 * LEXER RULES
 *------------------------------------------------------------------*/

//Keywords
SET	:	('s'|'S') ('e'|'E') ('t'|'T') ;
CREATE	:	('c'|'C') ('r'|'R') ('e'|'E') ('a'|'A') ('t'|'T') ('e'|'E') ;
NULL	:	('n'|'N') ('u'|'U') ('l'|'L') ('l'|'L') ;
STREAM	:	('s'|'S') ('t'|'T') ('r'|'R') ('e'|'E') ('a'|'A') ('m'|'M') ;
PARAMS	:	('p'|'P') ('a'|'A') ('r'|'R') ('a'|'A') ('m'|'M') ('s'|'S') ;

//Data types
SINT8	:	('s'|'S') ('i'|'I') ('n'|'N') ('t'|'T') '8' ;
SINT16	:	('s'|'S') ('i'|'I') ('n'|'N') ('t'|'T') '1' '6' ;
SINT32	:	('s'|'S') ('i'|'I') ('n'|'N') ('t'|'T') '3' '2' ;
SINT64	:	('s'|'S') ('i'|'I') ('n'|'N') ('t'|'T') '6' '4' ;
UINT8	:	('u'|'U') ('i'|'I') ('n'|'N') ('t'|'T') '8' ;
UINT16	:	('u'|'U') ('i'|'I') ('n'|'N') ('t'|'T') '1' '6' ;
UINT32	:	('u'|'U') ('i'|'I') ('n'|'N') ('t'|'T') '3' '2' ;
FLOAT	:	('f'|'F') ('l'|'L') ('o'|'O') ('a'|'A') ('t'|'T') ;
DOUBLE	:	('d'|'D') ('o'|'O') ('u'|'U') ('b'|'B') ('l'|'L') ('e'|'E') ;
BOOLEAN	:	('b'|'B') ('o'|'O') ('o'|'O') ('l'|'L') ('e'|'E') ('a'|'A') ('n'|'N') ;

IDENTIFIER
	:	LETTER ( LETTER | DIGIT | IDPUNC )+ ;

QUOTED_STRING
	:	QUOTE ( LETTER | DIGIT | WHITESPACE )+ QUOTE
	{
		//Strip the surrounding quotes
		String txt = getText(); 
		setText(txt.substring(1, txt.length() -1)); 
	};

WITHID  :	WITH WHITESPACE ID ;

WITHCODEC
	:	WITH WHITESPACE CODEC ;

INTEGER	:	DIGIT DIGIT* ;
NUMBER	:	DIGIT DIGIT* ('.' DIGIT+)?  ;

WHITESPACE : ( '\t' | ' ' | '\r' | '\n'| '\u000C' )+ 	{ $channel = HIDDEN; } ;

LINE_COMMENT 
	:	'//' .* '\n' { $channel = HIDDEN; } ;

fragment WITH	:	('w'|'W') ('i'|'I') ('t'|'T') ('h'|'H') ;
fragment ID	:	('i'|'I') ('d'|'D') ;
fragment CODEC	:	('c'|'C') ('o'|'O') ('d'|'D') ('e'|'E') ('c'|'C') ;

fragment LETTER	:	'a'..'z' | 'A'..'Z' ;
	
fragment DIGIT	:	'0'..'9' ;

fragment IDPUNC	:	'.' | '_' | '$' ;
