/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package Experiments;

import java.io.BufferedReader;
import java.io.File;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.RandomAccessFile;

/**
 * In FileAccess I try to see how well I can create and/or manage fixed size files.
 *
 * @author Jason Winnebeck
 */
public class FileAccess {
	private static final int BLOCK_SIZE = 512;
	private static final int NUM_BLOCKS = 512;

	public static void main( String[] args ) throws Exception {
		BufferedReader in = new BufferedReader( new InputStreamReader( System.in ) );
		System.out.print( "File name: " );
		String filename = in.readLine();
		File f = new File( filename );
		String path = f.getAbsolutePath();
		if ( f.exists() ) {
			System.out.println( "Testing " + path );
			testFile( path );
		} else {
			createFile( path );
			System.out.println( path + " created" );
		}
	}

	private static void testFile( String filename ) throws IOException {
		RandomAccessFile f = new RandomAccessFile( filename, "r" );

		System.out.println( "Length   = " + f.length() );
		long blocks = f.length() / BLOCK_SIZE;
		System.out.println( "Blocks   = " + blocks );
		System.out.println( "Leftover = " + ( f.length() % BLOCK_SIZE ) );

		//Can we now read all blocks?
		System.out.println( "Reading blocks" );
		byte[] block = new byte[ BLOCK_SIZE ];
		byte sum = 0;
		for ( int i = 0; i < blocks; ++i ) {
			f.seek( i * BLOCK_SIZE );
			f.readFully( block );

			for ( byte b : block )
				sum += b;
		}

		System.out.println( sum ); //only for curiousity

		//Can we read past end of file?
		try {
			f.seek( blocks * BLOCK_SIZE );
			f.readFully( block );
		} catch ( IOException e ) {
			System.out.println( "Expected: " );
			e.printStackTrace( System.out );
		}

		//Can we write to the start of the file?
//		f.seek( 0 );
//		Arrays.fill( block, (byte) 0 );
//		f.write( block );

		f.close();
	}

	private static void createFile( String filename ) throws IOException {
		RandomAccessFile f = new RandomAccessFile( filename, "rw" );

		System.out.println( "Length = " + f.length() );
		f.setLength( BLOCK_SIZE * NUM_BLOCKS );
		System.out.println( "Length = " + f.length() );

		f.close();
	}
}
