/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.Util;

import java.util.Collection;

/**
 * CheckUtils provides utitilies for precondition checking.
 *
 * @author Jason Winnebeck
 */
public class CheckUtils {
  /**
   * Checks if the given parameter is null, and if so throws an
   * IllegalArgumentException with an appropriate message.
   */
  public static void checkNull( Object parameter, String paramName )
      throws IllegalArgumentException {
    if ( parameter == null ) {
      throw new IllegalArgumentException( "Parameter " + paramName +
                                          " must not be null." );
    }
  }

  /**
   * Checks if the given parameter is null or has a size less than the given
   * size, and if so, throws an IllegalArgumentException with an appropriate
   * message.
   */
  public static void checkSize( Collection c, String paramName, int size ) {
    checkNull( c, paramName );
    if ( c.size() < size ) {
      throw new IllegalArgumentException(
          "Parameter " + paramName + " must contain at least " + size +
          " elements, but it only has " + c.size() + '.' );
    }
  }

	/**
	 * Checks if the given parameter is null or has a size less than the given
	 * size, and if so, throws an IllegalArgumentException with an appropriate
	 * message.
	 */
	public static void checkSize( Object[] arr, String paramName, int size ) {
	  checkNull( arr, paramName );
	  if ( arr.length < size ) {
	    throw new IllegalArgumentException(
	        "Parameter " + paramName + " must contain at least " + size +
	        " elements, but it only has " + arr.length + '.' );
	  }
	}
}
