/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.Util;

/**
 * The Factory interface describes classes implementing the factory pattern.
 *
 * @author Jason Winnebeck
 */
public interface Factory<T> {
	/**
	 * Creates or obtains an instance of type T based on the rules of this Factory. Most callers will
	 * want to assume that this method returns a non-null instance that cannot have any side-effects
	 * on the instances returned from subsequent calls to this method. In practical terms, that means
	 * a constant instance can only be returned for immutable types, else each call should create a
	 * new instance.
	 */
	public T create();
}
