/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.Util;

import java.io.Closeable;
import java.io.File;
import java.io.IOException;

/**
 * IOUtils contains useful IO utility methods.
 *
 * @author Jason Winnebeck
 */
public class IOUtils {
	/**
	 * Closes the given closeable, if it is not null, and ignores any exceptions that it throws.
	 */
	public static void safeClose( Closeable c ) {
		try {
			if ( c != null )
				c.close();
		} catch ( IOException e ) {
			//ignored
		}
	}

	/**
	 * Deletes the given file, if it is not null.
	 *
	 * @param f nullable File
	 *
	 * @return the result of {@link File#delete()}, or false if f is null
	 */
	public static boolean safeDelete( File f ) {
		if ( f != null )
			return f.delete();
		else
			return false;
	}
}
