/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.Util;

import java.io.PrintWriter;
import java.io.StringWriter;

/**
 * A StringPrintWriter gives an easy way to work with a lazy-initialized pair of StringWriter and
 * PrintWriter objects.
 */
public class StringPrintWriter {
	private StringWriter str;
	private PrintWriter out;

	public PrintWriter getPrintWriter() {
		ensureOutCreated();
		return out;
	}

	public void print( Object s ) {
		ensureOutCreated();
		out.print( s == null ? "null" : s.toString() );
	}

	public void println( Object s ) {
		ensureOutCreated();
		out.println( s == null ? "null" : s.toString() );
	}

	public void println() {
		ensureOutCreated();
		out.println();
	}

	public void format( String s, Object... args ) {
		ensureOutCreated();
		out.format( s, args );
	}

	public boolean wasUsed() {
		return out != null;
	}

	public String toString() {
		if ( out != null ) {
			out.flush();
			return str.toString();
		} else {
			return "";
		}
	}

	private void ensureOutCreated() {
		if ( out == null ) {
			str = new StringWriter();
			out = new PrintWriter( str );
		}
	}
}
