/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.io;

import java.io.DataInput;
import java.io.IOException;

/**
 * DataInputReadable is a class that can be read dynamically from a DataInput. Classes that
 * implement this interface must provide a no-args public constructor.
 * <p/>
 * It isn't strictly required that DataInputReadable extends DataOutputWritable, but helps to
 * clarify its purpose. The difference between a DataInputReadable and an object that is only
 * DataOutputWritable is that it can by dynamically loaded by class name, whereas an object that is
 * DataOutputWritable only can only be read if the type is known ahead of time.
 * <p/>
 * It is realized that this class very closely mirrors that of java.io.Externalizable, but the
 * reason why is because we want to tightly control the file format to not rely on the Java
 * serialization format. The only Java-specific parts of the file are the class names, which
 * actually could be simulated in other languages like C/C++ by using well-known names.
 *
 * @author Jason Winnebeck
 */
public interface DataInputReadable extends DataOutputWritable {
	public void read( DataInput input ) throws IOException;
}
