/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.io;

import java.io.DataOutput;
import java.io.IOException;

/**
 * DataOutputWriter provides the ability to write an Object of a given type to a DataOutput. A
 * specific DataOutputWriter is able to output only one object type.
 * <p/>
 * DataOutputWriters must be thread-safe.
 *
 * @author Jason Winnebeck
 */
public interface DataOutputWriter<T> {
	/**
	 * Writes the given value (type assumed) to the DataOutput.
	 *
	 * @param value possibly null instance (if this writer allows nulls)
	 * @param out   non-null DataOutput
	 */
	public void writeValue( T value, DataOutput out ) throws IOException;

	/**
	 * Returns the number of bytes that will be written to the DataOutput when writeValue is called.
	 */
	int getWrittenSize();
}
