/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.io;

import java.io.IOException;

/**
 * DebuggingBlockFile wraps another BlockFile implementation and prints information about file
 * accesses to standard output and then delegates to the wrapped BlockFile.
 *
 * @author Jason Winnebeck
 */
public class DebuggingBlockFile implements BlockFile {
	private final BlockFile wrapped;

	public DebuggingBlockFile( BlockFile wrapped ) {
		this.wrapped = wrapped;
	}

	public int getSize() {
		return wrapped.getSize();
	}

	public int getBlockSize() {
		return wrapped.getBlockSize();
	}

	public void readBlock( int num, byte[] data ) throws IOException {
		System.out.println( "Reading block " + num );
		wrapped.readBlock( num, data );
	}

	public int readBlocks( int startBlock, byte[] data ) throws IOException {
		int end = startBlock + data.length / getBlockSize();
		System.out.println( "Reading blocks " + startBlock + '-' + end );
		return wrapped.readBlocks( startBlock, data );
	}

	public void writeBlock( int num, byte[] data ) throws IOException {
		System.out.println( "Writing block " + num );
		wrapped.writeBlock( num, data );
	}

	public int writeBlocks( int startBlock, byte[] data ) throws IOException {
		int end = startBlock + data.length / getBlockSize();
		System.out.println( "Writing blocks " + startBlock + '-' + end );
		return wrapped.writeBlocks( startBlock, data );
	}

	public int writeBlocks( int startBlock, byte[] data, int start, int len ) throws IOException {
		int end = startBlock + data.length / getBlockSize();
		System.out.println( "Writing blocks " + startBlock + '-' + end );
		return wrapped.writeBlocks( startBlock, data, start, len );
	}

	public void close() throws IOException {
		System.out.println( "Closing file" );
		wrapped.close();
	}
}
