/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.model;

import org.gillius.realdb.BadFileException;

import java.io.DataOutput;
import java.io.IOException;
import java.nio.ByteBuffer;

/**
 * BlockPoolHeader
 * <p/>
 * TODO: document
 *
 * @author Jason Winnebeck
 */
public class BlockPoolHeader implements SequencedBlock {
	public static final SequencedBlockLoader<BlockPoolHeader> loader =
			new SequencedBlockLoader<BlockPoolHeader>() {
				public BlockPoolHeader load( byte[] serialized ) throws BadFileException {
					return new BlockPoolHeader( serialized );
				}
			};

	/**
	 * Returns the size of a BlockPoolHeader.
	 */
	public static int getSize() {
		//seqNum + firstUnusedBlock + checksum
		return 4 + 4 + 4;
	}

	private final int seqNum;
	private final int firstUnusedBlock;

	public BlockPoolHeader( int seqNum, int firstUnusedBlock ) {
		this.seqNum           = seqNum;
		this.firstUnusedBlock = firstUnusedBlock;
	}

	public BlockPoolHeader( byte[] data ) throws BadFileException {
		ByteBuffer buf = ByteBuffer.wrap( data );
		seqNum = buf.getInt();
		firstUnusedBlock = buf.getInt();

		//TODO: need a real checksum
		int sum = 1 + seqNum + firstUnusedBlock;
		int check = buf.getInt();
		if ( sum != check )
			throw new BadFileException( "Data corruption: checksum is not correct" );
	}

	public int getSeqNum() {
		return seqNum;
	}

	public int getFirstUnusedBlock() {
		return firstUnusedBlock;
	}

	public void write( DataOutput output ) throws IOException {
		output.writeInt( seqNum );
		output.writeInt( firstUnusedBlock );
		output.writeInt( 1 + seqNum + firstUnusedBlock );
	}

	public boolean equals( Object o ) {
		if ( this == o ) return true;
		if ( o == null || getClass() != o.getClass() ) return false;

		BlockPoolHeader poolBlock = (BlockPoolHeader) o;

		if ( firstUnusedBlock != poolBlock.firstUnusedBlock) return false;
		if ( seqNum           != poolBlock.seqNum          ) return false;

		return true;
	}

	public int hashCode() {
		int result;
		result = seqNum;
		result = 31 * result + firstUnusedBlock;
		return result;
	}
}