/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.model;

import org.gillius.realdb.BadFileException;

import java.io.IOException;

/**
 * DataBlockManager is a source for allocating and reading blocks in the system.
 *
 * @author Jason Winnebeck
 */
public interface DataBlockManager extends DataBlockSummaryReader {
	/**
	 * Returns the next block from this allocator. There should always be another block, as typically
	 * an allocator will free up space to find a new one if necessary. The block returned from this
	 * method must be closed before another can be retrieved.
	 *
	 * @return non-null empty DataBlock ready to write records of the given size
	 */
	public DataBlock getNextBlock( int recordSize ) throws IOException, BadFileException;

	/**
	 * Closes the block returned by {@link #getNextBlock(int)}, which schedules it to be written to
	 * disk and marks the intention that no more data will be added to it.
	 */
	public void closeBlock() throws IOException;

	/**
	 * Reads a block directly from the underlying storage (DataSection).
	 *
	 * @throws IOException      if the block could not be read
	 * @throws BadFileException if the block loaded was corrupted
	 */
	public DataBlock readBlock( int blockNum, int recordSize ) throws IOException, BadFileException;
}
