/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.model;

import org.gillius.realdb.BadFileException;

import java.io.IOException;

/**
 * DataBlockSummaryReader provides an interface for reading DataBlockHeaders to get their
 * information such as start and end times.
 *
 * @author Jason Winnebeck
 */
public interface DataBlockSummaryReader {

	/**
	 * Reads a block's Range directly from the underlying storage (DataSection). The range of a
	 * data block is the start and end of the first and last record timestamps.
	 *
	 * @throws IOException      if the block could not be read
	 * @throws BadFileException if the block loaded was corrupted
	 */
	public DefaultRange readBlockRange( int blockNum ) throws IOException, BadFileException;
}
