/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.model;

import org.gillius.realdb.BadFileException;

import java.io.IOException;

/**
 * DataStreamIndexReader specifies methods to read IndexBlocks in a {@link DataStreamIndex}.
 * Similar to collection iterators, a DataStreamIndexReader is invalidated whenever the
 * DataStreamIndex it came from is modified.
 *
 * @author Jason Winnebeck
 */
public interface DataStreamIndexReader extends RangeReader {

	/**
	 * Returns the number of {@link IndexBlock}s that can be read.
	 * @return
	 */
	public int getNumRanges();

	/**
	 * Reads the given IndexBlock.
	 */
	public IndexBlock getIndexBlock( int idx ) throws IOException, BadFileException;

	/**
	 * Returns just the {@link Range} of record times within all of the data blocks referenced by the
	 * IndexBlock.
	 */
	public Range getRange( int idx ) throws IOException, BadFileException;
}
