/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.model;

/**
 * DatabaseStatistics holds database statistics values.
 *
 * @author Jason Winnebeck
 */
public class DatabaseStatistics {
	private final int readCalls;
	private final int writeCalls;
	private final int readBlocks;
	private final int writtenBlocks;

	public DatabaseStatistics() {
		this( 0, 0, 0, 0);
	}

	public DatabaseStatistics( int readCalls, int writeCalls, int readBlocks, int writtenBlocks ) {
		this.readCalls = readCalls;
		this.writeCalls = writeCalls;
		this.readBlocks = readBlocks;
		this.writtenBlocks = writtenBlocks;
	}

	public int getReadCalls() {
		return readCalls;
	}

	public int getWriteCalls() {
		return writeCalls;
	}

	public int getReadBlocks() {
		return readBlocks;
	}

	public int getWrittenBlocks() {
		return writtenBlocks;
	}

	public DatabaseStatistics add( DatabaseStatistics other ) {
		return new DatabaseStatistics( readCalls + other.readCalls,
		                               writeCalls + other.writeCalls,
		                               readBlocks + other.readBlocks,
		                               writtenBlocks + other.writtenBlocks );
	}

	public DatabaseStatistics subtract( DatabaseStatistics other ) {
		return new DatabaseStatistics( readCalls - other.readCalls,
		                               writeCalls - other.writeCalls,
		                               readBlocks - other.readBlocks,
		                               writtenBlocks - other.writtenBlocks );
	}

	@Override
	public boolean equals( Object o ) {
		if ( this == o ) return true;
		if ( o == null || getClass() != o.getClass() ) return false;

		DatabaseStatistics that = (DatabaseStatistics) o;

		if ( readBlocks != that.readBlocks ) return false;
		if ( readCalls != that.readCalls ) return false;
		if ( writeCalls != that.writeCalls ) return false;
		if ( writtenBlocks != that.writtenBlocks ) return false;

		return true;
	}

	@Override
	public int hashCode() {
		int result = readCalls;
		result = 31 * result + writeCalls;
		result = 31 * result + readBlocks;
		result = 31 * result + writtenBlocks;
		return result;
	}

	@Override
	public String toString() {
		return "DatabaseStatistics{" +
		       "readCalls=" + readCalls +
		       ", writeCalls=" + writeCalls +
		       ", readBlocks=" + readBlocks +
		       ", writtenBlocks=" + writtenBlocks +
		       '}';
	}
}
