/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.model;

import org.gillius.realdb.model.data.ElementInterval;

/**
 * ElementReconstructor
 *
 * @author Jason Winnebeck
 */
public interface ElementReconstructor {
	/**
	 * Returns the number of previous Records needed to make a proper ElementInterval.
	 */
	public int getLookBehindDesired();

	/**
	 * Returns the number of future Records beyond the immediately following Record to make a proper
	 * ElementInterval.
	 */
	public int getLookAheadDesired();

	/**
	 * Returns an ElementInterval representing the value of the element between values[currentIndex]
	 * and values[currentIndex+1]. The size of the given arrays is at least 2 + {@link
	 * #getLookBehindDesired()} + {@link #getLookAheadDesired()}, and the value of currentIndex will be
	 * at least the value of {@link #getLookBehindDesired()}. At the start and end of a stream's
	 * values, the values array may contain nulls (the corresponding timestamps will be negative).
	 * However, at least always values[currentIndex] and values[currentIndex+1] will be defined.
	 * <p/>
	 * This method must not be affected by any mutable state after construction. In other words, for
	 * a single instance, every call with the same inputs to this method should return an equivalent
	 * ElementInterval. This is so the reconstructors can be shared.
	 *
	 * @param times        timestamps array corresponding directly to the values array, which must not
	 *                     be modified.
	 * @param values       sampled values of the element at the given timestamps, which must not be
	 *                     modified.
	 * @param currentIndex index of the sample that is the start of the ElementInterval.
	 *
	 * @return non-null ElementInterval
	 */
	public ElementInterval getInterval( long[] times, Object[] values, int currentIndex );
}
