/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.model.algorithms;

import org.gillius.realdb.model.data.ElementInterval;

/**
* FlatElementInterval is an ElementInterval where the value is constant over the whole interval.
*
* @author Jason Winnebeck
*/
public class FlatElementInterval implements ElementInterval {
	private final Object val;
	private final long duration;

	public FlatElementInterval( Object val, long duration ) {
		this.val = val;
		this.duration = duration;
	}

	public Object getValueAt( long time ) {
		return val;
	}

	public Object getAverageValue() {
		return val;
	}

	public Object getMaximumValue() {
		return val;
	}

	public Object getMinimumValue() {
		return val;
	}

	public double getIntegral() {
		if ( val instanceof Number ) {
			Number num = (Number) val;
			return num.doubleValue() * duration;
		} else {
			return Double.NaN;
		}
	}
}
