/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.model.algorithms;

import org.gillius.realdb.model.ElementReconstructor;
import org.gillius.realdb.model.data.ElementInterval;

/**
 * FlatElementReconstructor is an {@link ElementReconstructor} implementation that reconstructs by
 * assuming the object's value is constant over the entire interval.
 *
 * @author Jason Winnebeck
 */
class FlatElementReconstructor implements ElementReconstructor {
	/**
	 * A global default instance of this object, since it has no state the instance can be freely
	 * shared across all threads.
	 */
	public static final FlatElementReconstructor instance = new FlatElementReconstructor();

	public int getLookBehindDesired() {
		return 0;
	}

	public int getLookAheadDesired() {
		return 0;
	}

	public ElementInterval getInterval( long[] times, Object[] values, int currentIndex ) {
		return new FlatElementInterval( values[currentIndex],
		                                times[currentIndex + 1] - times[currentIndex] );
	}
}
