/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.model.algorithms;

import org.gillius.realdb.metadata.AbstractElementCodec;
import org.gillius.realdb.metadata.ElementType;
import org.gillius.realdb.model.ElementCompressor;
import org.gillius.realdb.model.ElementReconstructor;
import org.gillius.realdb.model.data.ElementInterval;

/**
 * SampledAlgorithm is a codec that always says the record should be written.
 *
 * @author Jason Winnebeck
 */
public class SampledAlgorithm extends AbstractElementCodec {
	private static final Compressor    comp  = new Compressor();
	private static final Reconstructor recon = new Reconstructor();

	public ElementCompressor getCompressor( ElementType type ) {
		return comp;
	}

	public ElementReconstructor getReconstructor( ElementType type ) {
		return recon;
	}

	public boolean equals( Object other ) {
		return this == other || getClass().equals( other.getClass() );
	}

	public int hashCode() {
		return 0;
	}

	public String toString() {
		return "SampledAlgorithm";
	}

	private static class Compressor implements ElementCompressor {
		public int getLookBehindDesired() {
			return 0;
		}

		public int getLookAheadDesired() {
			return 0;
		}

		public boolean handleNewValue( long[] times, Object[] values, int currentIndex ) {
			return true;
		}

		public void valueWritten( long time, Object value ) {
		}
	}

	private static class Reconstructor implements ElementReconstructor {
		public int getLookBehindDesired() {
			return 0;
		}

		public int getLookAheadDesired() {
			return 0;
		}

		public ElementInterval getInterval( long[] times, Object[] values, int currentIndex ) {
			return new SampledElementInterval( values[currentIndex] );
		}
	}

	private static class SampledElementInterval implements ElementInterval {
		private final Object val;

		private SampledElementInterval( Object val ) {
			this.val = val;
		}

		public Object getValueAt( long time ) {
			return val;
		}

		public Object getAverageValue() {
			return val;
		}

		public Object getMaximumValue() {
			return val;
		}

		public Object getMinimumValue() {
			return val;
		}

		public double getIntegral() {
			return Double.NaN;
		}
	}
}
