/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.model.algorithms;

import org.gillius.realdb.metadata.AbstractElementCodec;
import org.gillius.realdb.metadata.ElementType;
import org.gillius.realdb.model.ElementCompressor;
import org.gillius.realdb.model.ElementReconstructor;

/**
 * StepAlgorithm implements an ElementCodec that suppresses the output of values if the value has
 * not changed from the last recorded point. This is similar to a DeadbandAlgorithm with a deadband
 * of 0, except that this also works with numeric types.
 *
 * @author Jason Winnebeck
 */
public class StepAlgorithm extends AbstractElementCodec {
	private static final Compressor comp = new Compressor();

	public StepAlgorithm() {
	}

	public ElementCompressor getCompressor( ElementType type ) {
		return comp;
	}

	public ElementReconstructor getReconstructor( ElementType type ) {
		return FlatElementReconstructor.instance;
	}

	public boolean equals( Object o ) {
		if ( this == o ) return true;
		if ( o == null || getClass() != o.getClass() ) return false;
		return true;
	}

	public int hashCode() {
		return 0;
	}

	public String toString() {
		return "StepAlgorithm";
	}

	private static class Compressor implements ElementCompressor {
		public int getLookBehindDesired() {
			return 1;
		}

		public int getLookAheadDesired() {
			return 0;
		}

		public boolean handleNewValue( long[] times, Object[] values, int currentIndex ) {
			final Object lastValue = values[currentIndex - 1];
			final Object currValue = values[currentIndex];

			return ( lastValue == null && currValue != null ) ||
			       ( lastValue != null && !lastValue.equals( currValue ) );
		}

		public void valueWritten( long time, Object value ) {
		}
	}
}
