/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.model.data;

/**
 * DefaultStreamInterval provides a default implementation of {@link StreamInterval} through an
 * array of {@link ElementInterval} objects.
 *
 * @author Jason Winnebeck
 */
public class DefaultStreamInterval implements StreamInterval {
	private final long              startTime;
	private final long              endTime;
	private final ElementInterval[] elements;

	/**
	 * Constructs a DefaultStreamInterval with the given start and end time, and an array of elements
	 * that must never be modified. DefaultStreamInterval takes ownership of the elements array; this
	 * is to make cloning the array optional.
	 */
	public DefaultStreamInterval( long startTime, long endTime, ElementInterval[] elements ) {
		this.startTime = startTime;
		this.endTime   = endTime;
		this.elements  = elements;
	}

	public boolean isDiscontinuity() {
		return false;
	}

	public long getStartTime() {
		return startTime;
	}

	public long getEndTime() {
		return endTime;
	}

	public long getTimespan() {
		return endTime - startTime;
	}

	public int getNumElements() {
		return elements.length;
	}

	public Object getValueAt( long time, int element ) {
		return elements[ element ].getValueAt( time );
	}

	public Object getAverageValue( int element ) {
		return elements[ element ].getAverageValue();
	}

	public Object getMaximumValue( int element ) {
		return elements[ element ].getMaximumValue();
	}

	public Object getMinimumValue( int element ) {
		return elements[ element ].getMinimumValue();
	}

	public Number getIntegral( int element ) {
		double ret = elements[element].getIntegral();
		if ( Double.isNaN( ret ) )
			return null;
		else
			return ret;
	}
}
