/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.model.data;

import org.gillius.Util.Factory;
import org.gillius.realdb.metadata.RecordElement;
import org.gillius.realdb.model.ElementReconstructor;

/**
 * DefaultStreamReconstructorFactory is able to create new, independent instances of
 * {@link DefaultStreamReconstructor}s.
 *
 * @author Jason Winnebeck
 */
public class DefaultStreamReconstructorFactory implements Factory<DefaultStreamReconstructor> {
	private final ElementReconstructor[] recons;
	private final int pivot;
	private final int bufferLen;

	public DefaultStreamReconstructorFactory( RecordElement[] elements ) {
		recons = new ElementReconstructor[ elements.length ];

		int maxBehind = 0;
		int maxAhead  = 0;

		for ( int i = 0; i < elements.length; i++ ) {
			RecordElement element = elements[i];
			recons[i] = element.getCodec().getReconstructor( element.getType() );
			maxBehind = Math.max( maxBehind, recons[i].getLookBehindDesired() );
			maxAhead  = Math.max( maxAhead,  recons[i].getLookAheadDesired () );
		}

		bufferLen = maxBehind + 2 + maxAhead;
		pivot = maxBehind;
	}

	public DefaultStreamReconstructor create() {
		return new DefaultStreamReconstructor( recons, pivot, bufferLen );
	}
}
