/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.model.data;

/**
 * ElementInterval represents data from a single RecordElement within a StreamInterval.
 *
 * @author Jason Winnebeck
 */
public interface ElementInterval {
	/**
	 * Samples the value for this element at the given time. If the time is outside the interval, the
	 * results are undefined. IllegalArgumentException may be thrown, but is not required.
	 */
	public Object getValueAt( long time );

	/**
	 * Returns the average value for the element over this interval's time range. For non-numeric
	 * types, such as Boolean, this method returns the exact value.
	 */
	public Object getAverageValue();

	/**
	 * Returns the maximum value for the element over this interval's time range. For non-numeric
	 * types, such as Boolean, this method returns the exact value.
	 */
	public Object getMaximumValue();

	/**
	 * Returns the minimum value for the element over this interval's time range. For non-numeric
	 * types, such as Boolean, this method returns the exact value.
	 */
	public Object getMinimumValue();

	/**
	 * Returns the result of the definite integral between this interval's start and end times. For
	 * non-numeric ElementTypes (such as Boolean), or for ElementCodecs that do not represent
	 * continuous ranges (such as SampledAlgorithm) this method always returns NaN.
	 */
	public double getIntegral();
}
