/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.model.data;

import java.util.Arrays;

/**
 * PreservingRecordBuffer is a RecordBuffer that additionally holds a buffer of the original
 * Record objects.
 *
 * @author Jason Winnebeck
 */
public class PreservingRecordBuffer extends RecordBuffer {
	private final Record[] records;

	public PreservingRecordBuffer( int length, int elements, int pivot ) {
		super( length, elements, pivot );

		records = new Record[ length ];
	}

	/**
	 * Returns a reference to the Records array, which is of size {@link #getSize()}.
	 */
	public Record[] getRecords() {
		return records;
	}

	@Override
	public void clear() {
		super.clear();
		Arrays.fill( records, null );
	}

	@Override
	public void rotateEmpty( long time ) {
		super.rotateEmpty( time );

		System.arraycopy( records, 1, records, 0, records.length - 1 );
		records[ records.length - 1 ] = null;
	}

	@Override
	public void rotate( Record r ) {
		super.rotate( r );

		System.arraycopy( records, 1, records, 0, records.length - 1 );
		records[ records.length - 1 ] = r;
	}

	@Override
	public void dropPivot() {
		final int lookAhead = getLookAhead();
		if ( lookAhead > 0 ) {
			super.dropPivot();

			final int pivot = getPivot();
			System.arraycopy( records, pivot + 1, records, pivot, lookAhead );
		}
	}

	@Override
	public void fillLast( Record r ) {
		super.fillLast( r );

		records[ records.length - 1 ] = r;
	}
}
