/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.model.data;

/**
 * UnsignedInteger represents an unsigned 32-bit integer from 0 to 4294967295.
 *
 * @author Jason Winnebeck
 */
public final class UnsignedInteger extends Number implements Comparable<UnsignedInteger> {
	private final int value;

	public UnsignedInteger( long value ) {
		if ( value < 0L || value > 4294967295L )
			throw new IllegalArgumentException( "UnsignedInteger values are from 0 to 4294967295" );
		this.value = (int) value;
	}

	public UnsignedInteger( int value ) {
		this.value = value;
	}

	public int intValue() {
		return value;
	}

	public long longValue() {
		return value & 0xFFFFFFFFL;
	}

	public float floatValue() {
		return value & 0xFFFFFFFFL;
	}

	public double doubleValue() {
		return value & 0xFFFFFFFFL;
	}

	@Override
	public int compareTo( UnsignedInteger o ) {
		long me = longValue();
		long them = o.longValue();
		return me < them ? -1 : me == them ? 0 : 1;
	}

	@Override
	public boolean equals( Object o ) {
		if ( this == o ) return true;
		if ( o == null || getClass() != o.getClass() ) return false;

		UnsignedInteger that = (UnsignedInteger) o;

		if ( value != that.value ) return false;

		return true;
	}

	@Override
	public int hashCode() {
		return value;
	}

	public String toString() {
		return String.valueOf( longValue() );
	}
}
