/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.model.data;

/**
 * UnsignedShort represents an unsigned 16-bit number from 0 to 65535.
 *
 * @author Jason Winnebeck
 */
public final class UnsignedShort extends Number implements Comparable<UnsignedShort> {
	private final short value;

	public UnsignedShort( int value ) {
		if ( value < 0 || value > 65535 )
			throw new IllegalArgumentException( "UnsignedShort values are 0 to 65535" );
		this.value = (short) value;
	}

	public UnsignedShort( short value ) {
		this.value = value;
	}

	@Override
	public short shortValue() {
		return value;
	}

	public int intValue() {
		return value & 0xFFFF;
	}

	public long longValue() {
		return value & 0xFFFF;
	}

	public float floatValue() {
		return value & 0xFFFF;
	}

	public double doubleValue() {
		return value & 0xFFFF;
	}

	@Override
	public int compareTo( UnsignedShort o ) {
		int me = intValue();
		int them = o.intValue();
		return me < them ? -1 : me == them ? 0 : 1;
	}

	@Override
	public boolean equals( Object o ) {
		if ( this == o ) return true;
		if ( o == null || getClass() != o.getClass() ) return false;

		UnsignedShort that = (UnsignedShort) o;

		if ( value != that.value ) return false;

		return true;
	}

	@Override
	public int hashCode() {
		return (int) value;
	}

	public String toString() {
		return String.valueOf( intValue() );
	}
}
