/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.model.pool;

import java.io.DataInput;
import java.io.DataOutput;
import java.io.IOException;

/**
 * AddIndexTxEntry is a transaction log entry for adding a data block to an index.
 *
 * @author Jason Winnebeck
 */
public class AddIndexTxEntry extends IndexTxEntry {
	private final int lastBlock;

	public AddIndexTxEntry( int block, int index, int seqNum, int lastBlock ) {
		super( block, index, seqNum );
		this.lastBlock = lastBlock;
	}

	/**
	 * Given a DataInput where the type was already read, reads a new AddIndexTxEntry.
	 */
	public AddIndexTxEntry( DataInput in ) throws IOException {
		super( in );
		lastBlock = in.readInt();
	}

	public static int getWrittenSize() {
		return IndexTxEntry.getWrittenSize();
	}

	public int getLastBlock() {
		return lastBlock;
	}

	@Override
	public void write( DataOutput output ) throws IOException {
		super.write( output );
		output.writeInt( lastBlock );
	}

	@Override
	public TxEntryType getType() {
		return TxEntryType.Add;
	}
}
