/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.model.pool;

import java.io.DataInput;
import java.io.DataOutput;
import java.io.IOException;

/**
 * RemoveIndexTxEntry is a transaction log entry for removing a data block to an index.
 *
 * @author Jason Winnebeck
 */
public class RemoveIndexTxEntry extends IndexTxEntry {
	private final long nextBlockStartTime;

	/**
	 * Constructs a new RemoveIndexTxEntry.
	 *
	 * @param nextBlockStartTime The parameter for the DataIndex removeFirstBlock method.
	 */
	public RemoveIndexTxEntry( int block, int index, int seqNum, long nextBlockStartTime ) {
		super( block, index, seqNum );
		this.nextBlockStartTime = nextBlockStartTime;
	}

	/**
	 * Given a DataInput where the type was already read, reads a new RemoveIndexTxEntry.
	 */
	public RemoveIndexTxEntry( DataInput in ) throws IOException {
		super( in );
		nextBlockStartTime = in.readLong();
	}

	public static int getWrittenSize() {
		return IndexTxEntry.getWrittenSize() + 8;
	}

	@Override
	public void write( DataOutput output ) throws IOException {
		super.write( output );
		output.writeLong( nextBlockStartTime );
	}

	@Override
	public TxEntryType getType() {
		return TxEntryType.Remove;
	}

	public long getNextBlockStartTime() {
		return nextBlockStartTime;
	}

	@Override
	public boolean equals( Object o ) {
		if ( this == o ) return true;
		if ( o == null || getClass() != o.getClass() ) return false;
		if ( !super.equals( o ) ) return false;

		RemoveIndexTxEntry that = (RemoveIndexTxEntry) o;

		if ( nextBlockStartTime != that.nextBlockStartTime ) return false;

		return true;
	}

	@Override
	public int hashCode() {
		int result = super.hashCode();
		result = 31 * result + (int) ( nextBlockStartTime ^ ( nextBlockStartTime >>> 32 ) );
		return result;
	}
}
