/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.model.pool;

/**
 * TxEntryType describes a type of transaction log entry.
 *
 * @author Jason Winnebeck
 */
public enum TxEntryType {
	Remove( (byte) 1 ),
	Add( (byte) 2 ),
	FreeState( (byte) 3 ),
	RemoveFree( (byte) 4 );

	private final byte externalCode;

	private TxEntryType( byte externalCode ) {
		this.externalCode = externalCode;
	}

	public byte getExternalCode() {
		return externalCode;
	}

	public static TxEntryType getByExternalCode( byte code ) throws IllegalArgumentException {
		if ( code == Remove.getExternalCode() )
			return Remove;
		else if ( code == Add.getExternalCode() )
			return Add;
		else if ( code == FreeState.getExternalCode() )
			return FreeState;
		else if ( code == RemoveFree.getExternalCode() )
			return RemoveFree;
		else
			throw new IllegalArgumentException( "Unknown code " + code );
	}
}
