/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.util;

import java.util.Iterator;

/**
 * DBIteratorAdaptor allows a normal Iterator to masquerade as an DBIterator that never throws an
 * IOException.
 *
 * @author Jason Winnebeck
 */
public class DBIteratorAdaptor<T> implements DBIterator<T>, Iterator<T> {
	private final Iterator<? extends T> iter;

	public DBIteratorAdaptor( Iterator<? extends T> iter ) {
		this.iter = iter;
	}

	/**
	 * An alternative method to the constructor, to avoid extra generic parameters. This method is
	 * exactly as the constructor, but in many cases appears cleaner from a syntax viewpoint.
	 */
	public static <T> DBIteratorAdaptor<T> make( Iterator<T> iter ) {
		return new DBIteratorAdaptor<T>( iter );
	}

	public boolean hasNext() {
		return iter.hasNext();
	}

	public T next() {
		return iter.next();
	}

	public void remove() {
		iter.remove();
	}
}
