/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.io;

import org.junit.*;

import static org.junit.Assert.*;

/**
 * TestBitField tests the {@link BitField} class.
 *
 * @author Jason Winnebeck
 */
public class TestBitField {
	private BitField bf;

	@Before
	public void setUp() throws Exception {
		bf = new BitField( 16 );
	}

	@Test
	public void testGetSize() {
		assertEquals(  0, new BitField( 0 ).getSize() );
		assertEquals(  8, new BitField( 1 ).getSize() );
		assertEquals(  8, new BitField( 8 ).getSize() );
		assertEquals( 16, new BitField( 9 ).getSize() );
		assertEquals( 16, new BitField( 16 ).getSize() );
	}

	@Test
	public void testBitField() {

		assertArrayEquals( new byte[2], bf.getData() );

		for ( int i=0; i < bf.getSize(); ++i ) {
			assertFalse( bf.get( i ) );
		}

		bf.set( 0 );
		bf.set( 7 );
		bf.set( 8 );

		assertArrayEquals( new byte[] { (byte) 0x81, 0x01 },
		                   bf.getData() );

		assertTrue( bf.get( 0 ) );
		assertTrue( bf.get( 7 ) );
		assertTrue( bf.get( 8 ) );

		assertFalse( bf.get( 1 ) );
		assertFalse( bf.get( 2 ) );
		assertFalse( bf.get( 12 ) );

		bf.clear();
		assertArrayEquals( new byte[2], bf.getData() );
	}

	@Test( expected = IndexOutOfBoundsException.class )
	public void testSetLargeIndex() {
		bf.set( 17 );
	}

	@Test( expected = IndexOutOfBoundsException.class )
	public void testSetNegativeIndex() {
		bf.set( -1 );
	}

	@Test( expected = IndexOutOfBoundsException.class )
	public void testGetLargeIndex() {
		bf.get( 17 );
	}

	@Test( expected = IndexOutOfBoundsException.class )
	public void testGetNegativeIndex() {
		bf.get( -1 );
	}
}
