/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.io;

import junit.framework.TestCase;
import org.gillius.realdb.metadata.ElementType;
import org.gillius.realdb.model.data.UnsignedByte;
import org.gillius.realdb.model.data.UnsignedInteger;
import org.gillius.realdb.model.data.UnsignedShort;

import java.io.DataOutput;
import java.io.IOException;

import static org.easymock.EasyMock.*;

/**
 * TestElementWriterFactory tests the {@link ElementSerializerFactory} and the {@link DataOutputWriter}s
 * that it creates.
 *
 * @author Jason Winnebeck
 */
public class TestElementSerializerFactory extends TestCase {
	public void testSizes() throws Exception {
		assertEquals( 1, ElementSerializerFactory.getWriter( ElementType.Boolean ).getWrittenSize() );
		assertEquals( 4, ElementSerializerFactory.getWriter( ElementType.Float ).getWrittenSize() );
		assertEquals( 8, ElementSerializerFactory.getWriter( ElementType.Double ).getWrittenSize() );
		assertEquals( 1, ElementSerializerFactory.getWriter( ElementType.SInt8 ).getWrittenSize() );
		assertEquals( 2, ElementSerializerFactory.getWriter( ElementType.SInt16 ).getWrittenSize() );
		assertEquals( 4, ElementSerializerFactory.getWriter( ElementType.SInt32 ).getWrittenSize() );
		assertEquals( 8, ElementSerializerFactory.getWriter( ElementType.SInt64 ).getWrittenSize() );
		assertEquals( 1, ElementSerializerFactory.getWriter( ElementType.UInt8 ).getWrittenSize() );
		assertEquals( 2, ElementSerializerFactory.getWriter( ElementType.UInt16 ).getWrittenSize() );
		assertEquals( 4, ElementSerializerFactory.getWriter( ElementType.UInt32 ).getWrittenSize() );
	}

	public void testWriteNull() throws Exception {
		DataOutput out = createStrictMock( DataOutput.class );

		out.writeBoolean( false );
		out.writeFloat  ( 0.0f  );
		out.writeDouble ( 0.0   );
		out.writeByte   ( 0     );
		out.writeShort  ( 0     );
		out.writeInt    ( 0     );
		out.writeLong   ( 0     );
		out.writeByte   ( 0     );
		out.writeShort  ( 0     );
		out.writeInt    ( 0     );
		replay( out );

		writeValue( ElementType.Boolean, null, out );
		writeValue( ElementType.Float,   null, out );
		writeValue( ElementType.Double,  null, out );
		writeValue( ElementType.SInt8,   null, out );
		writeValue( ElementType.SInt16,  null, out );
		writeValue( ElementType.SInt32,  null, out );
		writeValue( ElementType.SInt64,  null, out );
		writeValue( ElementType.UInt8,   null, out );
		writeValue( ElementType.UInt16,  null, out );
		writeValue( ElementType.UInt32,  null, out );

		verify( out );
	}

	public void testWriteValue() throws Exception {
		DataOutput out = createStrictMock( DataOutput.class );

		out.writeBoolean( true           );
		out.writeFloat  ( 23.4f          );
		out.writeDouble ( 233.0          );
		out.writeByte   ( (byte )  -3    );
		out.writeShort  ( (short) -45    );
		out.writeInt    ( -56            );
		out.writeLong   ( -0xFFFFFFFFFFL );
		out.writeByte   ( (byte )  -1    );
		out.writeShort  ( (short)  -1    );
		out.writeInt    (  -1            );
		replay( out );

		writeValue( ElementType.Boolean, true,           out );
		writeValue( ElementType.Float,   23.4f,          out );
		writeValue( ElementType.Double,  233.0,          out );
		writeValue( ElementType.SInt8,   (byte )  -3,    out );
		writeValue( ElementType.SInt16,  (short) -45,    out );
		writeValue( ElementType.SInt32,  -56,            out );
		writeValue( ElementType.SInt64,  -0xFFFFFFFFFFL, out );
		writeValue( ElementType.UInt8,  new UnsignedByte   (   255       ), out );
		writeValue( ElementType.UInt16, new UnsignedShort  ( 65535       ), out );
		writeValue( ElementType.UInt32, new UnsignedInteger( 0xFFFFFFFFL ), out );

		verify( out );
	}

	private static void writeValue( ElementType type, Object value, DataOutput out )
			throws IOException {
		DataOutputWriter writer = ElementSerializerFactory.getWriter( type );
		writer.writeValue( value, out );
	}
}
