/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.io;

import org.junit.*;

import java.io.IOException;
import java.util.Arrays;
import java.util.Random;

import static org.junit.Assert.*;

/**
 * TestFailingBlockFile tests the {@link FailingBlockFile} class.
 *
 * @author Jason Winnebeck
 */
public class TestFailingBlockFile {
	private static final int BLOCK_SIZE = 100;

	private FailingBlockFile file;

	@Before
	public void setUp() {
		file = new FailingBlockFile( new ByteArrayBlockFile( BLOCK_SIZE, 5 ),
		                             new Random( 123456L ) );
	}

	@Test
	public void testFailure() throws IOException {
		byte[] data = new byte[ BLOCK_SIZE ];
		byte[] read = new byte[ BLOCK_SIZE ];
		Arrays.fill( data, (byte) 10 );

		file.writeBlock( 1, data );
		file.writeBlock( 2, data );

		file.readBlock( 1, read );
		assertArrayEquals( data, read );
		file.readBlock( 2, read );
		assertArrayEquals( data, read );

		file.setFailureCount( 1 );
		try {
			file.writeBlock( 2, data );
			fail( "IOException expected" );
		} catch ( IOException e ) {
			//expected
		}

		file.readBlock( 1, read );
		assertArrayEquals( data, read );
		file.readBlock( 2, read );
		assertFalse( Arrays.equals( data, read ) );
	}
}
