/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.io.rdl;

import junit.framework.TestCase;
import org.antlr.runtime.ANTLRStringStream;
import org.antlr.runtime.CommonTokenStream;
import org.gillius.realdb.metadata.DataStreamInfo;
import org.gillius.realdb.metadata.ElementType;
import org.gillius.realdb.metadata.RecordElement;
import org.gillius.realdb.model.algorithms.DeadbandAlgorithm;
import org.gillius.realdb.model.algorithms.SampledAlgorithm;

import java.util.ArrayList;
import java.util.List;

import static java.util.Collections.*;

/**
 * TestRDBDefinitionParser tests the {@link RDBDefinitionParser} class generated from the ANTLR v3
 * grammar for the RealDB Definition Language.
 *
 * @author Jason Winnebeck
 */
public class TestRDBDefinitionParser extends TestCase {
	private static final String testFile =
			"//This is a line comment\n" +
			"SET blockSize = 512\n" +
			"\n" +
			"CREATE STREAM Sine WITH ID 123 {\n" +
			"  value float WITH CODEC SampledAlgorithm\n" +
			"}\n" +
			"\n" +
			"CREATE STREAM \"Complex Stream\" WITH ID 5 {\n" +
			"  value float,\n" +
			"  confidence float NULL WITH CODEC org.gillius.realdb.model.algorithms.DeadbandAlgorithm PARAMS (deadband=10.0)\n" +
			"}";

	private RDBDefinitionParser parser;

	@Override
	protected void setUp() throws Exception {
		super.setUp();

		RDBDefinitionLexer lexer = new RDBDefinitionLexer( new ANTLRStringStream( testFile ) );
		CommonTokenStream tokens = new CommonTokenStream( lexer );
		parser = new RDBDefinitionParser( tokens );
	}

	public void testParse() throws Exception {
		RDLFile file = parser.statements();

		assertEquals( singletonMap( "blockSize", "512" ), file.getOptionsMap() );

		RecordElement[] elements = new RecordElement[] {
				new RecordElement( 0, "value", new SampledAlgorithm(), ElementType.Float, false )
		};
		List<DataStreamInfo> infos = new ArrayList<DataStreamInfo>();
		infos.add( new DataStreamInfo( 123, "Sine", elements ) );
		elements = new RecordElement[] {
				new RecordElement( 0, "value", new SampledAlgorithm(), ElementType.Float, false ),
				new RecordElement( 1, "confidence", new DeadbandAlgorithm( 10.0 ), ElementType.Float, true )
		};
		infos.add( new DataStreamInfo( 5, "Complex Stream", elements ) );

		assertEquals( infos, file.getStreamInfos() );
	}
}
