/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.io.rdl;

import org.gillius.realdb.BadFileException;
import org.junit.*;

/**
 * TestRDLFile tests the {@link RDLFile} class.
 *
 * @author Jason Winnebeck
 */
public class TestRDLFile {
	@Test( expected = BadFileException.class )
	public void testBadLoad1() throws Exception {
		String badRDL = "SET blockSize     = 512\n" +
		                "SET fileSize      = 512,000\n" + //comma is bad!
		                "SET maxStreams    = 3\n" +
		                "SET dataBlockSize = 2\n" +
		                "CREATE STREAM Test0 WITH ID 0 {value sint32 WITH CODEC SampledAlgorithm}\n" +
		                "CREATE STREAM Test1 WITH ID 1 {value sint32 WITH CODEC SampledAlgorithm}";

		RDLFile.load( badRDL );
	}

	@Ignore( "Not sure how to actually implement this given Antlr" )
	@Test( expected = BadFileException.class )
	public void testBadLoad2() throws Exception {
		String badRDL = "asdfasdfadsf";

		RDLFile.load( badRDL );
	}

	@Test
	public void testGoodLoad() throws Exception {
		String rdl = "SET blockSize     = 512\n" +
		             "SET fileSize      = 512000\n" + //comma is bad!
		             "SET maxStreams    = 3\n" +
		             "SET dataBlockSize = 2\n" +
		             "CREATE STREAM Test0 WITH ID 0 {value sint32 WITH CODEC SampledAlgorithm}\n" +
		             "CREATE STREAM Test1 WITH ID 1 {value sint32 WITH CODEC SampledAlgorithm}";

		RDLFile.load( rdl );
	}
}
