/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.metadata;

import junit.framework.TestCase;
import org.gillius.realdb.io.ByteArrayBlockFile;
import org.gillius.realdb.io.DowUtil;
import org.gillius.realdb.model.algorithms.StepAlgorithm;

import java.io.IOException;
import java.util.Collections;
import java.util.List;

import static org.easymock.EasyMock.*;

/**
 * TestMetadataSection tests the {@link MetadataSection} class.
 *
 * @author Jason Winnebeck
 */
public class TestMetadataSection extends TestCase {

	/**
	 * Tests the simple creation of a metadata section with a single stream with a single element.
	 */
	public void testCreate() {
		ElementCodec codec = createNiceMock( ElementCodec.class );

		RecordElement[] elements = new RecordElement[] {
			new RecordElement( 0, "value", codec, ElementType.Float, false )
		};

		List<DataStreamInfo> streamInfos = Collections.singletonList(
				new DataStreamInfo( 0, "Name", elements ) );
		new MetadataSection( 512, streamInfos, 5 );
	}

	/**
	 * Tests that we can save and load a simple MetadataSection.
	 */
	public void testRoundtrip() throws IOException {
		//We can't use mocks in this one because of the dynamic classname-based loading
		RecordElement[] elements = new RecordElement[] {
			new RecordElement( 0, "value", new StepAlgorithm(), ElementType.Float, false )
		};

		List<DataStreamInfo> streamInfos = Collections.singletonList(
				new DataStreamInfo( 0, "Name", elements ) );
		MetadataSection section = new MetadataSection( 512, streamInfos, 5 );

		ByteArrayBlockFile file = new ByteArrayBlockFile( 512, 10 ); //must be large enough
		file.writeBlocks( 0, DowUtil.serialize( section ) );

		MetadataSection read = new MetadataSection( file, 0 );
		assertEquals( section, read );
	}
}
