/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.metadata;

import junit.framework.TestCase;
import org.gillius.realdb.io.DowUtil;
import org.gillius.realdb.model.ElementCompressor;
import org.gillius.realdb.model.ElementReconstructor;

import java.io.ByteArrayInputStream;
import java.io.DataInput;
import java.io.DataInputStream;
import java.io.DataOutput;
import java.io.IOException;

/**
 * TestRecordElement tests the {@link RecordElement} class.
 *
 * @author Jason Winnebeck
 */
public class TestRecordElement extends TestCase {
	public void testRoundTrip() throws Exception {
		BasicElementCodec codec = new BasicElementCodec();
		RecordElement r = new RecordElement( 2, "Testing", codec, ElementType.SInt32, true );

		byte[] data = DowUtil.serialize( r );
		assertEquals( 1, codec.writeCalls );
		assertEquals( 0, codec.readCalls );

		DataInput input = new DataInputStream( new ByteArrayInputStream( data ) );
		RecordElement read = RecordElement.read( 2, input );

		assertEquals( r, read );
		assertEquals( 1, ((BasicElementCodec)read.getCodec()).readCalls );
		assertEquals( 0, ((BasicElementCodec)read.getCodec()).writeCalls );
	}

	/**
	 * Unfortunately we can't use a mock here because we need a class that can be loaded by
	 * Class.forName( x ).newInstance().
	 */
	public static class BasicElementCodec extends AbstractElementCodec {
		public int readCalls = 0;
		public int writeCalls = 0;

		public ElementCompressor getCompressor( ElementType type ) {
			return null;
		}

		public ElementReconstructor getReconstructor( ElementType type ) {
			return null;
		}

		public void read( DataInput input ) throws IOException {
			++readCalls;
		}

		public void write( DataOutput output ) throws IOException {
			++writeCalls;
		}

		public boolean equals( Object other ) {
			return this == other || getClass().equals( other.getClass() );
		}

		public int hashCode() {
			return 0;
		}
	}
}
