/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.model;

import org.gillius.realdb.BadFileException;
import org.gillius.realdb.io.DowUtil;
import org.junit.*;

import java.util.Random;

import static org.junit.Assert.*;

/**
 * TestDataIndexHeader tests the {@link DataIndexHeader} class.
 *
 * @author Jason Winnebeck
 */
public class TestDataIndexHeader {
	@Test
	public void testRoundTrip() throws Exception {
		//I tried the JUnit 4.4 theories here, but I like the explicit method better.
		testRoundTrip( new DataIndexHeader( 5, 4, false, 10 ) );
		testRoundTrip( new DataIndexHeader( 0, 0, false, 0 ) );
		testRoundTrip( new DataIndexHeader( 5, 4, true, 10 ) );
	}

	private static void testRoundTrip( DataIndexHeader header ) throws Exception {
		byte[] serialized = DowUtil.serialize( header );
		assertEquals( DataIndexHeader.getSize(), serialized.length );
		assertEquals( header, new DataIndexHeader( serialized ) );
	}

	@Test( expected = BadFileException.class )
	public void testZeros() throws Exception {
		byte[] zeros = new byte[DataIndexHeader.getSize()];
		new DataIndexHeader( zeros );
	}

	/**
	 * Tests 15 (same) random data sets all fail to load. This is brittle if the block's size changes
	 * as the data won't be the same as in previous tests, so a failure should be examined by hand to
	 * see if a random dataset really is valid.
	 */
	@Test
	public void testRandom() throws Exception {
		byte[] random = new byte[DataIndexHeader.getSize()];
		Random rnd = new Random( 120304506789L );

		for ( int i = 0; i < 15; ++i ) {
			rnd.nextBytes( random );
			try {
				new DataIndexHeader( random );
				fail( "Expected BadFileException" );
			} catch ( BadFileException e ) {
				//ignore, expected
			}
		}
	}

	@Test( expected = BadFileException.class )
	public void testManyZeros() throws Exception {
		byte[] zeros = new byte[512];
		new DataIndexHeader( zeros );
	}
}
