/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.model;

import org.gillius.realdb.io.BlockFile;
import org.gillius.realdb.io.ByteArrayBlockFile;
import org.junit.*;

import static org.easymock.EasyMock.*;
import static org.junit.Assert.*;

/**
 * TestDefaultCircularQueueBlockIO tests the {@link DefaultCircularQueueBlockIO} class.
 *
 * @author Jason Winnebeck
 */
public class TestDefaultCircularQueueBlockIO {
	private DefaultCircularQueueBlockIO io;

	@Before
	public void setUp() throws Exception {
		BlockFile bf = new ByteArrayBlockFile( 512, 5 );
		io = new DefaultCircularQueueBlockIO( bf, 1, bf.getSize() - 1 );
	}

	@Test
	public void testFormat() throws Exception {
		BlockFile bf = createMock( "bf", BlockFile.class );

		expect( bf.getBlockSize() ).andStubReturn( 512 );
		expect( bf.getSize() ).andStubReturn( 5 );

		bf.writeBlock( eq( 1 ), (byte[]) anyObject() );
		bf.writeBlock( eq( 2 ), (byte[]) anyObject() );
		bf.writeBlock( eq( 3 ), (byte[]) anyObject() );
		bf.writeBlock( eq( 4 ), (byte[]) anyObject() );

		replay( bf );
		io = new DefaultCircularQueueBlockIO( bf, 1, bf.getSize() - 1 );
		io.format();
		verify( bf );
	}

	@Test
	public void testWrite() throws Exception {
		BlockFile bf = createMock( "bf", BlockFile.class );

		expect( bf.getBlockSize() ).andStubReturn( 512 );
		expect( bf.getSize() ).andStubReturn( 5 );

		bf.writeBlock( eq( 1 ), (byte[]) anyObject() );

		replay( bf );
		io = new DefaultCircularQueueBlockIO( bf, 1, bf.getSize() - 1 );
		io.writeBlock( 0, new CircularQueueState(), new byte[0], 0, 0 );
		verify( bf );
	}

	@Test
	public void testReadWrite() throws Exception {
		byte[] data = { 1, 2, 3 };

		io.writeBlock( 0, new CircularQueueState(), data, 0, data.length );

		assertArrayEquals( data, io.getData( 0 ) );
	}

	@Test
	public void testGetStateNotAltHead() throws Exception {
		CircularQueueState state = new CircularQueueState( 1, 2, true, 3 );

		io.writeBlock( 1, state, new byte[0], 0, 0 );

		assertEquals( state, io.getState( 1 ) );
	}

	@Test
	public void testGetStateAltHead() throws Exception {
		CircularQueueState state = new CircularQueueState( 1, 2, false, 3 );

		io.writeBlock( io.getAltHeadIndex(), state, new byte[0], 0, 0 );

		assertEquals( state, io.getState( io.getAltHeadIndex() ) );
	}
}
