/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.model;

import org.gillius.realdb.BadFileException;
import org.gillius.realdb.io.DowUtil;
import org.junit.*;

import static org.junit.Assert.*;

/**
 * TestIndexBlock tests the {@link IndexBlock} class.
 *
 * @author Jason Winnebeck
 */
public class TestIndexBlock {
	private IndexBlock block;

	@Before
	public void setUp() throws Exception {
		block = new IndexBlock( 15, 5600, 10000, new int[] { 1, 4, 5 } );
	}

	@Test
	public void testRoundTrip() throws Exception {
		byte[] serialized = DowUtil.serialize( block );
		assertEquals( block, new IndexBlock( serialized ) );
	}

	@Test
	public void testEmptyBlock() throws Exception {
		IndexBlock empty = new IndexBlock( 0 );
		byte[] serialized = DowUtil.serialize( empty );
		assertEquals( empty, new IndexBlock( serialized ) );
	}

	@Test
	public void testGetMinSize() throws Exception {
		IndexBlock smallest = new IndexBlock( 1 );
		assertEquals( IndexBlock.getMinSize(), DowUtil.getSize( smallest ) );
	}

	@Test
	public void testGetSize() throws Exception {
		int expectedSize = IndexBlock.getSize( block.getDataBlocks().length );
		assertEquals( expectedSize, DowUtil.getSize( block ) );
	}

	@Test( expected = BadFileException.class )
	public void testZeros() throws Exception {
		byte[] zeros = new byte[IndexBlock.getMinSize()];
		new IndexBlock( zeros );
	}

	@Test( expected = BadFileException.class )
	public void testManyZeros() throws Exception {
		byte[] zeros = new byte[1024];
		new IndexBlock( zeros );
	}

	@Test
	public void testGetMaxDataBlocks() {
		assertEquals( 0, IndexBlock.getMaxDataBlocks( IndexBlock.getMinSize() ) );
		assertEquals( 5, IndexBlock.getMaxDataBlocks( IndexBlock.getMinSize() + 20 ) );
	}
}
