/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.model;

import org.gillius.realdb.BadFileException;
import org.junit.*;

import java.io.IOException;
import java.util.Arrays;

import static org.gillius.realdb.model.RangeReaderUtil.*;
import static org.junit.Assert.*;

/**
 * TestRangeReaderUtil tests the {@link RangeReaderUtil} class.
 *
 * @author Jason Winnebeck
 */
public class TestRangeReaderUtil {
	private Range[] ranges;

	@Before
	public void setUp() throws Exception {
		ranges = new Range[] {
				new DefaultRange( 50, 100 ),
				new DefaultRange( 150, 200 ),
				new DefaultRange( 250, 300 ),
				new DefaultRange( 350, 400 )
		};
	}

	@Test( expected = IllegalArgumentException.class )
	public void testFindRangeOnEmpty() throws Exception {
		RangeReader reader = new ArrayRangeReader( new Range[0] );

		findRange( reader, 100 );
	}

	@Test
	public void testFindRangeOnSingle() throws Exception {
		RangeReader reader = new ArrayRangeReader( Arrays.copyOf( ranges, 2 ) );

		assertEquals( 0, findRange( reader, 40 ) );
		assertEquals( 0, findRange( reader, 50 ) );
		assertEquals( 0, findRange( reader, 75 ) );
		assertEquals( 0, findRange( reader, 100 ) );
		assertEquals( 0, findRange( reader, 125 ) );

		assertEquals( 1, findRange( reader, 150 ) );
		assertEquals( 1, findRange( reader, 175 ) );
		assertEquals( 1, findRange( reader, 200 ) );
		assertEquals( 1, findRange( reader, 225 ) );
	}

	@Test
	public void testFindRange() throws Exception {
		RangeReader reader = new ArrayRangeReader( ranges );

		assertEquals( 0, findRange( reader, 40 ) );
		assertEquals( 0, findRange( reader, 50 ) );
		assertEquals( 0, findRange( reader, 75 ) );
		assertEquals( 0, findRange( reader, 100 ) );
		assertEquals( 0, findRange( reader, 125 ) );

		assertEquals( 1, findRange( reader, 150 ) );
		assertEquals( 1, findRange( reader, 175 ) );
		assertEquals( 1, findRange( reader, 200 ) );
		assertEquals( 1, findRange( reader, 225 ) );

		assertEquals( 2, findRange( reader, 250 ) );
		assertEquals( 2, findRange( reader, 275 ) );
		assertEquals( 2, findRange( reader, 300 ) );
		assertEquals( 2, findRange( reader, 325 ) );

		assertEquals( 3, findRange( reader, 350 ) );
		assertEquals( 3, findRange( reader, 375 ) );
		assertEquals( 3, findRange( reader, 400 ) );
		assertEquals( 3, findRange( reader, 450 ) );
	}

	private static class ArrayRangeReader implements RangeReader {
		private final Range[] ranges;

		private ArrayRangeReader( Range[] ranges ) {
			this.ranges = ranges;
		}

		public int getNumRanges() {
			return ranges.length;
		}

		public Range getRange( int idx ) throws IOException, BadFileException {
			return ranges[ idx ];
		}
	}
}
