/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.model;

import org.gillius.realdb.BadFileException;
import org.gillius.realdb.io.DowUtil;
import org.junit.*;

import static org.junit.Assert.*;

/**
 * TestRawSequencedBlock tests the {@link RawSequencedBlock} class.
 *
 * @author Jason Winnebeck
 */
public class TestRawSequencedBlock {

	@Test
	public void testRoundTrip() throws Exception {
		RawSequencedBlock block = new RawSequencedBlock( 5, new byte[] { 0, 12, (byte) 200 } );
		byte[] serialized = DowUtil.serialize( block );
		assertEquals( block, new RawSequencedBlock( serialized ) );
	}

	@Test
	public void testEmptyBlock() throws Exception {
		RawSequencedBlock empty = new RawSequencedBlock( 0, new byte[] { } );
		byte[] serialized = DowUtil.serialize( empty );
		assertEquals( empty, new RawSequencedBlock( serialized ) );
	}

	@Test
	public void testGetMinSize() throws Exception {
		RawSequencedBlock smallest = new RawSequencedBlock( 0, new byte[] { } );
		assertEquals( RawSequencedBlock.getMinSize(), DowUtil.getSize( smallest ) );
	}

	@Test( expected = BadFileException.class )
	public void testZeros() throws Exception {
		byte[] zeros = new byte[RawSequencedBlock.getMinSize()];
		new RawSequencedBlock( zeros );
	}

	@Test( expected = BadFileException.class )
	public void testManyZeros() throws Exception {
		byte[] zeros = new byte[1024];
		new RawSequencedBlock( zeros );
	}
}
