/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.model;

import org.gillius.realdb.BadFileException;
import org.junit.*;

import static org.easymock.EasyMock.*;
import static org.junit.Assert.*;

/**
 * TestSequenceBlockUtil tests the {@link SequencedBlockUtil} class.
 *
 * @author Jason Winnebeck
 */
@SuppressWarnings( { "ThrowableInstanceNeverThrown" } )
public class TestSequenceBlockUtil {
	private byte[] a;
	private byte[] b;
	private byte[] c;
	private SequencedBlock blockA;
	private SequencedBlock blockB;
	private SequencedBlock blockC;
	private SequencedBlockLoader<?> sbl;
	private int[] i;

	@Before
	public void setUp() throws Exception {
		a = new byte[0];
		b = new byte[0];
		c = new byte[0];
		blockA = createMock( "A", SequencedBlock.class );
		blockB = createMock( "B", SequencedBlock.class );
		blockC = createMock( "C", SequencedBlock.class );

		expect( blockA.getSeqNum() ).andStubReturn(  5 );
		expect( blockB.getSeqNum() ).andStubReturn( 10 );
		expect( blockC.getSeqNum() ).andStubReturn( 15 );
		replay( blockA, blockB, blockC );

		sbl = createStrictMock( SequencedBlockLoader.class );
		i = new int[] { 12345 };
	}

	@Test
	public void testLoadBestBlock1() throws Exception {
		expect( sbl.load( a ) ).andThrow( new BadFileException( "doif" ) );
		expect( sbl.load( b ) ).andReturn( blockB );
		expect( sbl.load( c ) ).andReturn( blockC );
		replay( sbl );

		SequencedBlock result = SequencedBlockUtil.loadBestBlock( sbl, i, a, b, c );

		assertEquals( 2, i[0] );
		assertSame( blockC, result );
	}

	@Test
	public void testLoadBestBlock2() throws Exception {
		expect( sbl.load( a ) ).andReturn( blockA );
		expect( sbl.load( c ) ).andReturn( blockC );
		expect( sbl.load( b ) ).andReturn( blockB );
		replay( sbl );

		SequencedBlock result = SequencedBlockUtil.loadBestBlock( sbl, i, a, c, b );

		assertEquals( 1, i[0] );
		assertSame( blockC, result );
	}

	@Test
	public void testLoadBestBlock3() throws Exception {
		expect( sbl.load( a ) ).andReturn( blockA );
		expect( sbl.load( c ) ).andReturn( blockC );
		expect( sbl.load( b ) ).andReturn( blockB );
		replay( sbl );

		SequencedBlock result = SequencedBlockUtil.loadBestBlock( sbl, null, a, c, b );
		assertSame( blockC, result );
	}

	@Test( expected = BadFileException.class )
	public void testLoadBestBlockAllFail() throws Exception {
		expect( sbl.load( (byte[])anyObject() ) ).andStubThrow( new BadFileException( "doif" ) );
		replay( sbl );

		SequencedBlockUtil.loadBestBlock( sbl, i, new byte[0], new byte[0] );
		assertEquals( 12345, i[0] );
	}
}
