/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.model.algorithms;

import org.gillius.realdb.metadata.ElementType;
import org.gillius.realdb.model.ElementCompressor;
import org.junit.*;

import static org.junit.Assert.*;

/**
 * TestDeadbandAlgorithm tests the {@link DeadbandAlgorithm} class.
 *
 * @author Jason Winnebeck
 */
public class TestDeadbandAlgorithm {
	private ElementCompressor comp;

	@Before
	public void setUp() throws Exception {
		DeadbandAlgorithm alg = new DeadbandAlgorithm( 10.0 );
		comp = alg.getCompressor( ElementType.Float );
	}

	@Test
	public void testCompressor() throws Exception {
		assertTrue( comp.handleNewValue( new long[] { -1, 10 },
		                                 new Object[] { null, 13.0f },
		                                 1 ) );

		assertTrue( comp.handleNewValue( new long[] { 10, 20 },
		                                 new Object[] { 2.0f, 13.0f },
		                                 1 ) );

		assertFalse( comp.handleNewValue( new long[] { 10, 20 },
		                                  new Object[] { 12.0f, 13.0f },
		                                  1 ) );
	}

	/**
	 * See if the compressor handles nulls/discontinuities properly.
	 */
	@Test
	public void testTransitionToAndFromNull() throws Exception {
		assertTrue( comp.handleNewValue( new long[] { 10, 20 },
		                                 new Object[] { 2.0f, null },
		                                 1 ) );

		assertTrue( comp.handleNewValue( new long[] { 10, 20 },
		                                 new Object[] { null, 2.0f },
		                                 1 ) );

		assertFalse( comp.handleNewValue( new long[] { 10, 20 },
		                                  new Object[] { null, null },
		                                  1 ) );
	}
}
