/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.model.pool;

import org.easymock.*;
import org.gillius.realdb.io.DataOutputWritable;
import org.junit.*;

import java.util.HashSet;
import java.util.Set;

import static java.util.Arrays.*;
import static org.easymock.EasyMock.*;
import static org.junit.Assert.*;

/**
 * TestDefaultBlockPool tests some portions of {@link DefaultBlockPool}.
 *
 * @author Jason Winnebeck
 */
public class TestDefaultBlockPool {

	@Test
	public void testOpenWithOpenTransactions() throws Exception {
		TransactionLog log = createMock( "log", TransactionLog.class );
		Set<Integer> openTx = asSet( 5, 6 );

		log.setHeaderWriter( isA( DataOutputWritable.class ) );
		log.loadOpenTransactions( isA( TxEntryHandler.class ) );
		expectLastCall().andAnswer( new IAnswer<Object>() {
			@Override
			public Object answer() throws Throwable {
				TxEntryHandler handler = (TxEntryHandler) getCurrentArguments()[0];
				handler.handleEntry( new FreeStateTxEntry( 2 ) );
				handler.handleEntry( new RemoveFreeTxEntry( 2 ) );
				handler.handleEntry( new RemoveFreeTxEntry( 3 ) );
				return null;
			}
		} );
		expect( log.getOpenTransactions() ).andReturn( openTx );
		replay( log );

		DefaultBlockPool pool = new DefaultBlockPool( log, 50 );
		pool.open();

		verify( log );

		assertEquals( 50, pool.getNumDataBlocks() );
		assertEquals( 4, pool.getNextUnusedBlock() );
		assertEquals( openTx, pool.getReclaimableBlocks() );
	}

	private static <T> Set<T> asSet( T... items ) {
		return new HashSet<T>( asList( items ) );
	}
}
