/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.model.pool;

import org.easymock.*;
import org.junit.*;

import java.io.Flushable;

import static org.easymock.EasyMock.*;

/**
 * TestDefaultTransaction tests the {@link DefaultTransaction} class.
 *
 * @author Jason Winnebeck
 */
public class TestDefaultTransaction {
	private DefaultTransaction tx;

	private IMocksControl ctrl;
	private Flushable a;
	private Flushable b;
	private Flushable c;

	@Before
	public void setUp() {
		tx = new DefaultTransaction();

		ctrl = createStrictControl();
		a = ctrl.createMock( "a", Flushable.class );
		b = ctrl.createMock( "b", Flushable.class );
		c = ctrl.createMock( "c", Flushable.class );
	}

	@Test
	public void testNoFlushCommit() throws Exception {
		ctrl.replay();

		tx.addAction( a );
		tx.addAction( b );
		tx.addAction( c );

		ctrl.verify(); //assert no flushing yet
		ctrl.reset();
		a.flush();
		b.flush();
		c.flush();
		ctrl.replay();

		tx.commit();

		ctrl.verify(); //assert all flushed, in order
	}

	@Test
	public void testPartialFlushAndCommit() throws Exception {
		a.flush();
		ctrl.replay();

		tx.addAction( a );
		Flushable f = tx.addAction( b );
		tx.addAction( c );
		f.flush();

		ctrl.verify(); //assert only a is flushed
		ctrl.reset();
		b.flush();
		c.flush();
		ctrl.replay();

		tx.commit();

		ctrl.verify();
	}

	@Test( expected = IllegalStateException.class )
	public void testAddAfterCommit() throws Exception {
		tx.addAction( a );
		tx.commit();
		tx.addAction( b );
	}
}
