/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.realdb.tools;

import junit.framework.TestCase;
import org.gillius.realdb.BadFileException;
import org.gillius.realdb.io.ByteArrayBlockFile;
import org.gillius.realdb.metadata.DataStreamInfo;
import org.gillius.realdb.metadata.ElementType;
import org.gillius.realdb.metadata.MetadataSection;
import org.gillius.realdb.metadata.RecordElement;
import org.gillius.realdb.model.Database;
import org.gillius.realdb.model.algorithms.SampledAlgorithm;

import java.io.IOException;
import java.util.Collections;
import java.util.List;

/**
 * TestDatabaseBuilder tests the {@link DatabaseBuilder} class.
 *
 * @author Jason Winnebeck
 */
public class TestDatabaseBuilder extends TestCase {
	private DatabaseBuilder builder;

	@Override
	protected void setUp() throws Exception {
		super.setUp();

		builder = new DatabaseBuilder();
	}

	public void testCreate() throws IOException, BadFileException {
		//We can't use mocks in this one because of the dynamic classname-based loading
		RecordElement[] elements = new RecordElement[] {
			new RecordElement( 0, "value", new SampledAlgorithm(), ElementType.Float, false )
		};

		List<DataStreamInfo> streamInfos = Collections.singletonList(
				new DataStreamInfo( 0, "Name", elements ) );
		MetadataSection section = new MetadataSection( 1, streamInfos, 5 );

		builder.setBlockSize( 1024 );
		builder.setFileSize( builder.getBlockSize() * 100 );
		builder.setMetadata( section );
		assertTrue( builder.validate( null ) );

		ByteArrayBlockFile bf = new ByteArrayBlockFile( 1024, 100 );
		Database db = builder.createDatabase( bf );

		assertEquals( section, db.getMetadata() );

		Database reloaded = Database.load( bf );
		assertEquals( section, reloaded.getMetadata() );
		//TODO: more asserts when Database is completed
	}

	public void testValidate() {
		assertFalse( builder.validate( null ) );
		builder.setBlockSize( 1024 );
		assertFalse( builder.validate( null ) );
		builder.setFileSize( builder.getBlockSize() * 100 );
		assertFalse( builder.validate( null ) );
	}
}
