/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.RealDBDemo;

import org.gillius.realdb.io.rdl.RDLFile;
import org.gillius.realdb.tools.DatabaseBuilder;

import javax.swing.*;
import java.io.File;

/**
 * Demo provides a demonstration of high-speed "reliable" writing to a database file.
 *
 * @author Jason Winnebeck
 */
public class Demo {
	public static void main( String[] args ) {
		final JFrame splash = new JFrame( "RealDB Demo" );
		splash.add( new JLabel( "Loading RealDB Demo..." ) );
		splash.pack();
		splash.setLocationRelativeTo( null );
		splash.setVisible( true );

		try {
			ConfigPanel config = new ConfigPanel();
			if ( !config.showDialog( splash, "RealDB Demo Configuration" ) )
				System.exit( 0 );

			RDLFile rdl    = RDLFile.load( config.getRDL() );
			File    dbFile = config.getFile();
			//Create the database (We'll reload it later to get the final version).
			new DatabaseBuilder( rdl ).createDatabase( dbFile ).close();

			DemoDatabaseLoader loader = new DemoDatabaseLoader( dbFile,          config.getBlockSize() );
			DemoRunner         runner = new DemoRunner        ( loader.reload(), loader                );
			DemoUI ui = new DemoUI( runner, loader );
			ui.showFrame( "RealDB Demo", JFrame.EXIT_ON_CLOSE );
			SwingUtilities.invokeLater( new Runnable() {
				public void run() {
					splash.dispose();
				}
			} );
			runner.run();

		} catch ( Exception e ) {
			e.printStackTrace();
			JOptionPane.showMessageDialog( splash, e, "RealDB Demo Error", JOptionPane.ERROR_MESSAGE );
			System.exit( 1 );
		}
	}
}
