/*
 * RealDB Project - Copyright (c) 2008-2010 by Jason Winnebeck
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, see <http://www.gnu.org/licenses>.
 *
 * Additional permission under GNU GPL version 3 section 7
 *
 * If you modify this Program, or any covered work, by linking or combining it with JUnit (or a
 * modified version of that library), containing parts covered by the terms of Common Public
 * License, 1.0, the licensors of this Program grant you additional permission to convey the
 * resulting work.
 */
package org.gillius.RealDBDemo;

import org.gillius.realdb.BadFileException;
import org.gillius.realdb.io.BlockFile;
import org.gillius.realdb.io.ProfilingBlockFile;
import org.gillius.realdb.io.RandomAccessBlockFile;
import org.gillius.realdb.io.TriggeredFailingBlockFile;
import org.gillius.realdb.metadata.FileHeader;
import org.gillius.realdb.model.Database;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.RandomAccessFile;
import java.util.Random;

/**
 * DemoDatabaseLoader
*
* @author Jason Winnebeck
*/
public class DemoDatabaseLoader implements DatabaseLoader {
	private final File dbFile;
	private final int  blockSize;

	private TriggeredFailingBlockFile blockFile;

	public DemoDatabaseLoader( File dbFile, int blockSize ) {
		this.dbFile    = dbFile;
		this.blockSize = blockSize;
	}

	public Database reload() throws IOException, BadFileException {
		FileInputStream fis = new FileInputStream( dbFile );
		FileHeader header = FileHeader.getHeader( fis );
		fis.close();

		RandomAccessFile raf = new RandomAccessFile( dbFile, "rwd" );
		BlockFile file = new RandomAccessBlockFile( raf, blockSize, header.getNumBlocks() );
		blockFile = new TriggeredFailingBlockFile( new Random(), file );
		return Database.load( new ProfilingBlockFile( blockFile ) );
	}

	public TriggeredFailingBlockFile getBlockFile() {
		return blockFile;
	}
}
